@@ -1,15 +1,15 @@
 #!/usr/bin/env python
-# pylint: disable=C0116,W0613
+# pylint: disable=unused-argument
 # This program is dedicated to the public domain under the CC0 license.
 
 """Bot that explains Telegram's "Deep Linking Parameters" functionality.
 
 This program is dedicated to the public domain under the CC0 license.
 
-This Bot uses the Updater class to handle the bot.
+This Bot uses the Application class to handle the bot.
 
 First, a few handler functions are defined. Then, those functions are passed to
-the Dispatcher and registered at their respective places.
+the Application and registered at their respective places.
 Then, the bot is started and runs until we press Ctrl-C on the command line.
 
 Usage:
@@ -20,22 +20,18 @@ bot.
 
 import logging
 
-from telegram import ParseMode, InlineKeyboardMarkup, InlineKeyboardButton, Update
-from telegram.ext import (
-    Updater,
-    CommandHandler,
-    CallbackQueryHandler,
-    Filters,
-    CallbackContext,
-)
+from telegram import InlineKeyboardButton, InlineKeyboardMarkup, Update, helpers
+from telegram.constants import ParseMode
+from telegram.ext import Application, CallbackQueryHandler, CommandHandler, ContextTypes, filters
 
 # Enable logging
-from telegram.utils import helpers
-
 logging.basicConfig(
     format="%(asctime)s - %(name)s - %(levelname)s - %(message)s", level=logging.INFO
 )
 
+# set higher logging level for httpx to avoid all GET and POST requests being logged
+logging.getLogger("httpx").setLevel(logging.WARNING)
+
 logger = logging.getLogger(__name__)
 
 # Define constants that will allow us to reuse the deep-linking parameters.
@@ -48,39 +44,38 @@ SO_COOL = "so-cool"
 KEYBOARD_CALLBACKDATA = "keyboard-callback-data"
 
 
-def start(update: Update, context: CallbackContext) -> None:
+async def start(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
     """Send a deep-linked URL when the command /start is issued."""
     bot = context.bot
     url = helpers.create_deep_linked_url(bot.username, CHECK_THIS_OUT, group=True)
     text = "Feel free to tell your friends about it:\n\n" + url
-    update.message.reply_text(text)
+    await update.message.reply_text(text)
 
 
-def deep_linked_level_1(update: Update, context: CallbackContext) -> None:
+async def deep_linked_level_1(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
     """Reached through the CHECK_THIS_OUT payload"""
     bot = context.bot
     url = helpers.create_deep_linked_url(bot.username, SO_COOL)
     text = (
-        "Awesome, you just accessed hidden functionality! "
-        "Now let's get back to the private chat."
+        "Awesome, you just accessed hidden functionality! Now let's get back to the private chat."
     )
     keyboard = InlineKeyboardMarkup.from_button(
         InlineKeyboardButton(text="Continue here!", url=url)
     )
-    update.message.reply_text(text, reply_markup=keyboard)
+    await update.message.reply_text(text, reply_markup=keyboard)
 
 
-def deep_linked_level_2(update: Update, context: CallbackContext) -> None:
+async def deep_linked_level_2(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
     """Reached through the SO_COOL payload"""
     bot = context.bot
     url = helpers.create_deep_linked_url(bot.username, USING_ENTITIES)
-    text = f"You can also mask the deep-linked URLs as links: [▶️ CLICK HERE]({url})."
-    update.message.reply_text(text, parse_mode=ParseMode.MARKDOWN, disable_web_page_preview=True)
+    text = f'You can also mask the deep-linked URLs as links: <a href="{url}">▶️ CLICK HERE</a>.'
+    await update.message.reply_text(text, parse_mode=ParseMode.HTML, disable_web_page_preview=True)
 
 
-def deep_linked_level_3(update: Update, context: CallbackContext) -> None:
+async def deep_linked_level_3(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
     """Reached through the USING_ENTITIES payload"""
-    update.message.reply_text(
+    await update.message.reply_text(
         "It is also possible to make deep-linking using InlineKeyboardButtons.",
         reply_markup=InlineKeyboardMarkup(
             [[InlineKeyboardButton(text="Like this!", callback_data=KEYBOARD_CALLBACKDATA)]]
@@ -88,65 +83,57 @@ def deep_linked_level_3(update: Update, context: CallbackContext) -> None:
     )
 
 
-def deep_link_level_3_callback(update: Update, context: CallbackContext) -> None:
+async def deep_link_level_3_callback(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
     """Answers CallbackQuery with deeplinking url."""
     bot = context.bot
     url = helpers.create_deep_linked_url(bot.username, USING_KEYBOARD)
-    update.callback_query.answer(url=url)
+    await update.callback_query.answer(url=url)
 
 
-def deep_linked_level_4(update: Update, context: CallbackContext) -> None:
+async def deep_linked_level_4(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
     """Reached through the USING_KEYBOARD payload"""
     payload = context.args
-    update.message.reply_text(
+    await update.message.reply_text(
         f"Congratulations! This is as deep as it gets 👏🏻\n\nThe payload was: {payload}"
     )
 
 
 def main() -> None:
     """Start the bot."""
-    # Create the Updater and pass it your bot's token.
-    updater = Updater("TOKEN")
-
-    # Get the dispatcher to register handlers
-    dispatcher = updater.dispatcher
+    # Create the Application and pass it your bot's token.
+    application = Application.builder().token("TOKEN").build()
 
     # More info on what deep linking actually is (read this first if it's unclear to you):
-    # https://core.telegram.org/bots#deep-linking
+    # https://core.telegram.org/bots/features#deep-linking
 
     # Register a deep-linking handler
-    dispatcher.add_handler(
-        CommandHandler("start", deep_linked_level_1, Filters.regex(CHECK_THIS_OUT))
+    application.add_handler(
+        CommandHandler("start", deep_linked_level_1, filters.Regex(CHECK_THIS_OUT))
     )
 
     # This one works with a textual link instead of an URL
-    dispatcher.add_handler(CommandHandler("start", deep_linked_level_2, Filters.regex(SO_COOL)))
+    application.add_handler(CommandHandler("start", deep_linked_level_2, filters.Regex(SO_COOL)))
 
     # We can also pass on the deep-linking payload
-    dispatcher.add_handler(
-        CommandHandler("start", deep_linked_level_3, Filters.regex(USING_ENTITIES))
+    application.add_handler(
+        CommandHandler("start", deep_linked_level_3, filters.Regex(USING_ENTITIES))
     )
 
     # Possible with inline keyboard buttons as well
-    dispatcher.add_handler(
-        CommandHandler("start", deep_linked_level_4, Filters.regex(USING_KEYBOARD))
+    application.add_handler(
+        CommandHandler("start", deep_linked_level_4, filters.Regex(USING_KEYBOARD))
     )
 
     # register callback handler for inline keyboard button
-    dispatcher.add_handler(
+    application.add_handler(
         CallbackQueryHandler(deep_link_level_3_callback, pattern=KEYBOARD_CALLBACKDATA)
     )
 
     # Make sure the deep-linking handlers occur *before* the normal /start handler.
-    dispatcher.add_handler(CommandHandler("start", start))
+    application.add_handler(CommandHandler("start", start))
 
-    # Start the Bot
-    updater.start_polling()
-
-    # Run the bot until you press Ctrl-C or the process receives SIGINT,
-    # SIGTERM or SIGABRT. This should be used most of the time, since
-    # start_polling() is non-blocking and will stop the bot gracefully.
-    updater.idle()
+    # Run the bot until the user presses Ctrl-C
+    application.run_polling(allowed_updates=Update.ALL_TYPES)
 
 
 if __name__ == "__main__":
