@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# pylint: disable=C0116,W0613
+# pylint: disable=unused-argument
 # This program is dedicated to the public domain under the CC0 license.
 
 """Basic example for a bot that can receive payment from user."""
@@ -8,34 +8,38 @@ import logging
 
 from telegram import LabeledPrice, ShippingOption, Update
 from telegram.ext import (
-    Updater,
+    Application,
     CommandHandler,
+    ContextTypes,
     MessageHandler,
-    Filters,
     PreCheckoutQueryHandler,
     ShippingQueryHandler,
-    CallbackContext,
+    filters,
 )
 
 # Enable logging
 logging.basicConfig(
-    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s', level=logging.INFO
+    format="%(asctime)s - %(name)s - %(levelname)s - %(message)s", level=logging.INFO
 )
+# set higher logging level for httpx to avoid all GET and POST requests being logged
+logging.getLogger("httpx").setLevel(logging.WARNING)
 
 logger = logging.getLogger(__name__)
 
+PAYMENT_PROVIDER_TOKEN = "PAYMENT_PROVIDER_TOKEN"
 
-def start_callback(update: Update, context: CallbackContext) -> None:
+
+async def start_callback(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
     """Displays info on how to use the bot."""
     msg = (
         "Use /shipping to get an invoice for shipping-payment, or /noshipping for an "
         "invoice without shipping."
     )
 
-    update.message.reply_text(msg)
+    await update.message.reply_text(msg)
 
 
-def start_with_shipping_callback(update: Update, context: CallbackContext) -> None:
+async def start_with_shipping_callback(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
     """Sends an invoice with shipping-payment."""
     chat_id = update.message.chat_id
     title = "Payment Example"
@@ -43,7 +47,6 @@ def start_with_shipping_callback(update: Update, context: CallbackContext) -> No
     # select a payload just for you to recognize its the donation from your bot
     payload = "Custom-Payload"
     # In order to get a provider_token see https://core.telegram.org/bots/payments#getting-a-token
-    provider_token = "PROVIDER_TOKEN"
     currency = "USD"
     # price in dollars
     price = 1
@@ -53,12 +56,12 @@ def start_with_shipping_callback(update: Update, context: CallbackContext) -> No
 
     # optionally pass need_name=True, need_phone_number=True,
     # need_email=True, need_shipping_address=True, is_flexible=True
-    context.bot.send_invoice(
+    await context.bot.send_invoice(
         chat_id,
         title,
         description,
         payload,
-        provider_token,
+        PAYMENT_PROVIDER_TOKEN,
         currency,
         prices,
         need_name=True,
@@ -69,7 +72,9 @@ def start_with_shipping_callback(update: Update, context: CallbackContext) -> No
     )
 
 
-def start_without_shipping_callback(update: Update, context: CallbackContext) -> None:
+async def start_without_shipping_callback(
+    update: Update, context: ContextTypes.DEFAULT_TYPE
+) -> None:
     """Sends an invoice without shipping-payment."""
     chat_id = update.message.chat_id
     title = "Payment Example"
@@ -77,7 +82,6 @@ def start_without_shipping_callback(update: Update, context: CallbackContext) ->
     # select a payload just for you to recognize its the donation from your bot
     payload = "Custom-Payload"
     # In order to get a provider_token see https://core.telegram.org/bots/payments#getting-a-token
-    provider_token = "PROVIDER_TOKEN"
     currency = "USD"
     # price in dollars
     price = 1
@@ -86,79 +90,73 @@ def start_without_shipping_callback(update: Update, context: CallbackContext) ->
 
     # optionally pass need_name=True, need_phone_number=True,
     # need_email=True, need_shipping_address=True, is_flexible=True
-    context.bot.send_invoice(
-        chat_id, title, description, payload, provider_token, currency, prices
+    await context.bot.send_invoice(
+        chat_id, title, description, payload, PAYMENT_PROVIDER_TOKEN, currency, prices
     )
 
 
-def shipping_callback(update: Update, context: CallbackContext) -> None:
+async def shipping_callback(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
     """Answers the ShippingQuery with ShippingOptions"""
     query = update.shipping_query
     # check the payload, is this from your bot?
-    if query.invoice_payload != 'Custom-Payload':
+    if query.invoice_payload != "Custom-Payload":
         # answer False pre_checkout_query
-        query.answer(ok=False, error_message="Something went wrong...")
+        await query.answer(ok=False, error_message="Something went wrong...")
         return
 
     # First option has a single LabeledPrice
-    options = [ShippingOption('1', 'Shipping Option A', [LabeledPrice('A', 100)])]
+    options = [ShippingOption("1", "Shipping Option A", [LabeledPrice("A", 100)])]
     # second option has an array of LabeledPrice objects
-    price_list = [LabeledPrice('B1', 150), LabeledPrice('B2', 200)]
-    options.append(ShippingOption('2', 'Shipping Option B', price_list))
-    query.answer(ok=True, shipping_options=options)
+    price_list = [LabeledPrice("B1", 150), LabeledPrice("B2", 200)]
+    options.append(ShippingOption("2", "Shipping Option B", price_list))
+    await query.answer(ok=True, shipping_options=options)
 
 
 # after (optional) shipping, it's the pre-checkout
-def precheckout_callback(update: Update, context: CallbackContext) -> None:
+async def precheckout_callback(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
     """Answers the PreQecheckoutQuery"""
     query = update.pre_checkout_query
     # check the payload, is this from your bot?
-    if query.invoice_payload != 'Custom-Payload':
+    if query.invoice_payload != "Custom-Payload":
         # answer False pre_checkout_query
-        query.answer(ok=False, error_message="Something went wrong...")
+        await query.answer(ok=False, error_message="Something went wrong...")
     else:
-        query.answer(ok=True)
+        await query.answer(ok=True)
 
 
 # finally, after contacting the payment provider...
-def successful_payment_callback(update: Update, context: CallbackContext) -> None:
+async def successful_payment_callback(update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
     """Confirms the successful payment."""
     # do something after successfully receiving payment?
-    update.message.reply_text("Thank you for your payment!")
+    await update.message.reply_text("Thank you for your payment!")
 
 
 def main() -> None:
     """Run the bot."""
-    # Create the Updater and pass it your bot's token.
-    updater = Updater("TOKEN")
-
-    # Get the dispatcher to register handlers
-    dispatcher = updater.dispatcher
+    # Create the Application and pass it your bot's token.
+    application = Application.builder().token("TOKEN").build()
 
     # simple start function
-    dispatcher.add_handler(CommandHandler("start", start_callback))
+    application.add_handler(CommandHandler("start", start_callback))
 
     # Add command handler to start the payment invoice
-    dispatcher.add_handler(CommandHandler("shipping", start_with_shipping_callback))
-    dispatcher.add_handler(CommandHandler("noshipping", start_without_shipping_callback))
+    application.add_handler(CommandHandler("shipping", start_with_shipping_callback))
+    application.add_handler(CommandHandler("noshipping", start_without_shipping_callback))
 
     # Optional handler if your product requires shipping
-    dispatcher.add_handler(ShippingQueryHandler(shipping_callback))
+    application.add_handler(ShippingQueryHandler(shipping_callback))
 
     # Pre-checkout handler to final check
-    dispatcher.add_handler(PreCheckoutQueryHandler(precheckout_callback))
+    application.add_handler(PreCheckoutQueryHandler(precheckout_callback))
 
     # Success! Notify your user!
-    dispatcher.add_handler(MessageHandler(Filters.successful_payment, successful_payment_callback))
+    application.add_handler(
+        MessageHandler(filters.SUCCESSFUL_PAYMENT, successful_payment_callback)
+    )
 
-    # Start the Bot
-    updater.start_polling()
-
-    # Run the bot until you press Ctrl-C or the process receives SIGINT,
-    # SIGTERM or SIGABRT. This should be used most of the time, since
-    # start_polling() is non-blocking and will stop the bot gracefully.
-    updater.idle()
+    # Run the bot until the user presses Ctrl-C
+    application.run_polling(allowed_updates=Update.ALL_TYPES)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
