@@ -1,7 +1,7 @@
 # !/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -16,20 +16,18 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-# pylint: disable=C0114
+# pylint: disable=missing-module-docstring
 import subprocess
 import sys
 from typing import Optional
 
-import certifi
-
 from . import __version__ as telegram_ver
 from .constants import BOT_API_VERSION
 
 
 def _git_revision() -> Optional[str]:
     try:
-        output = subprocess.check_output(  # skipcq: BAN-B607
+        output = subprocess.check_output(
             ["git", "describe", "--long", "--tags"], stderr=subprocess.STDOUT
         )
     except (subprocess.SubprocessError, OSError):
@@ -37,18 +35,19 @@ def _git_revision() -> Optional[str]:
     return output.decode().strip()
 
 
-def print_ver_info() -> None:  # skipcq: PY-D0003
+def print_ver_info() -> None:
+    """Prints version information for python-telegram-bot, the Bot API and Python."""
     git_revision = _git_revision()
-    print(f'python-telegram-bot {telegram_ver}' + (f' ({git_revision})' if git_revision else ''))
-    print(f'Bot API {BOT_API_VERSION}')
-    print(f'certifi {certifi.__version__}')  # type: ignore[attr-defined]
-    sys_version = sys.version.replace('\n', ' ')
-    print(f'Python {sys_version}')
+    print(f"python-telegram-bot {telegram_ver}" + (f" ({git_revision})" if git_revision else ""))
+    print(f"Bot API {BOT_API_VERSION}")
+    sys_version = sys.version.replace("\n", " ")
+    print(f"Python {sys_version}")
 
 
-def main() -> None:  # skipcq: PY-D0003
+def main() -> None:
+    """Prints version information for python-telegram-bot, the Bot API and Python."""
     print_ver_info()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
