@@ -63,7 +63,7 @@ class ChatJoinRequest(TelegramObject):
             request. This number may have more than 32 significant bits and some programming
             languages may have difficulty/silent defects in interpreting it. But it has at most 52
             significant bits, so a 64-bit integer or double-precision float type are safe for
-            storing this identifier. The bot can use this identifier for 24 hours to send messages
+            storing this identifier. The bot can use this identifier for 5 minutes to send messages
             until the join request is processed, assuming no other administrator contacted the
             user.
 
@@ -100,7 +100,7 @@ class ChatJoinRequest(TelegramObject):
 
     """
 
-    __slots__ = ("chat", "from_user", "date", "bio", "invite_link", "user_chat_id")
+    __slots__ = ("bio", "chat", "date", "from_user", "invite_link", "user_chat_id")
 
     def __init__(
         self,
