@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -17,6 +17,7 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Telegram Audio."""
+from typing import Optional
 
 from telegram._files._basethumbedmedium import _BaseThumbedMedium
 from telegram._files.photosize import PhotoSize
@@ -29,6 +30,9 @@ class Audio(_BaseThumbedMedium):
     Objects of this class are comparable in terms of equality. Two objects of this class are
     considered equal, if their :attr:`file_unique_id` is equal.
 
+    .. versionchanged:: 20.5
+      |removed_thumb_note|
+
 
     Args:
         file_id (:obj:`str`): Identifier for this file, which can be used to download
@@ -42,9 +46,11 @@ class Audio(_BaseThumbedMedium):
         file_name (:obj:`str`, optional): Original filename as defined by sender.
         mime_type (:obj:`str`, optional): MIME type of the file as defined by sender.
         file_size (:obj:`int`, optional): File size in bytes.
-        thumb (:class:`telegram.PhotoSize`, optional): Thumbnail of the album cover to
+        thumbnail (:class:`telegram.PhotoSize`, optional): Thumbnail of the album cover to
             which the music file belongs.
 
+            .. versionadded:: 20.2
+
     Attributes:
         file_id (:obj:`str`): Identifier for this file, which can be used to download
             or reuse the file.
@@ -57,9 +63,11 @@ class Audio(_BaseThumbedMedium):
         file_name (:obj:`str`): Optional. Original filename as defined by sender.
         mime_type (:obj:`str`): Optional. MIME type of the file as defined by sender.
         file_size (:obj:`int`): Optional. File size in bytes.
-        thumb (:class:`telegram.PhotoSize`): Optional. Thumbnail of the album cover to
+        thumbnail (:class:`telegram.PhotoSize`): Optional. Thumbnail of the album cover to
             which the music file belongs.
 
+            .. versionadded:: 20.2
+
 
     """
 
@@ -70,27 +78,27 @@ class Audio(_BaseThumbedMedium):
         file_id: str,
         file_unique_id: str,
         duration: int,
-        performer: str = None,
-        title: str = None,
-        mime_type: str = None,
-        file_size: int = None,
-        thumb: PhotoSize = None,
-        file_name: str = None,
+        performer: Optional[str] = None,
+        title: Optional[str] = None,
+        mime_type: Optional[str] = None,
+        file_size: Optional[int] = None,
+        file_name: Optional[str] = None,
+        thumbnail: Optional[PhotoSize] = None,
         *,
-        api_kwargs: JSONDict = None,
+        api_kwargs: Optional[JSONDict] = None,
     ):
         super().__init__(
             file_id=file_id,
             file_unique_id=file_unique_id,
             file_size=file_size,
-            thumb=thumb,
+            thumbnail=thumbnail,
             api_kwargs=api_kwargs,
         )
         with self._unfrozen():
             # Required
-            self.duration = duration
+            self.duration: int = duration
             # Optional
-            self.performer = performer
-            self.title = title
-            self.mime_type = mime_type
-            self.file_name = file_name
+            self.performer: Optional[str] = performer
+            self.title: Optional[str] = title
+            self.mime_type: Optional[str] = mime_type
+            self.file_name: Optional[str] = file_name
