@@ -74,11 +74,11 @@ class File(TelegramObject):
     """
 
     __slots__ = (
+        "_credentials",
         "file_id",
+        "file_path",
         "file_size",
         "file_unique_id",
-        "file_path",
-        "_credentials",
     )
 
     def __init__(
@@ -99,7 +99,7 @@ class File(TelegramObject):
         self.file_size: Optional[int] = file_size
         self.file_path: Optional[str] = file_path
 
-        self._credentials: Optional["FileCredentials"] = None
+        self._credentials: Optional[FileCredentials] = None
 
         self._id_attrs = (self.file_unique_id,)
 
@@ -231,6 +231,10 @@ class File(TelegramObject):
 
         .. seealso:: :wiki:`Working with Files and Media <Working-with-Files-and-Media>`
 
+        Hint:
+            If you want to immediately read the data from ``out`` after calling this method, you
+            should call ``out.seek(0)`` first. See also :meth:`io.IOBase.seek`.
+
         .. versionadded:: 20.0
 
         Args:
