@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,9 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """Base class for Telegram InputMedia Objects."""
-from typing import Optional, Sequence, Union
+from typing import Optional, Sequence, Tuple, Union
 
+from telegram import constants
 from telegram._files.animation import Animation
 from telegram._files.audio import Audio
 from telegram._files.document import Document
@@ -27,6 +28,7 @@ from telegram._files.photosize import PhotoSize
 from telegram._files.video import Video
 from telegram._messageentity import MessageEntity
 from telegram._telegramobject import TelegramObject
+from telegram._utils import enum
 from telegram._utils.argumentparsing import parse_sequence_arg
 from telegram._utils.defaultvalue import DEFAULT_NONE
 from telegram._utils.files import parse_file_input
@@ -87,27 +89,29 @@ class InputMedia(TelegramObject):
         self,
         media_type: str,
         media: Union[str, InputFile, MediaType],
-        caption: str = None,
-        caption_entities: Sequence[MessageEntity] = None,
+        caption: Optional[str] = None,
+        caption_entities: Optional[Sequence[MessageEntity]] = None,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
         *,
-        api_kwargs: JSONDict = None,
+        api_kwargs: Optional[JSONDict] = None,
     ):
         super().__init__(api_kwargs=api_kwargs)
-        self.type = media_type
-        self.media = media
-        self.caption = caption
-        self.caption_entities = parse_sequence_arg(caption_entities)
-        self.parse_mode = parse_mode
+        self.type: str = enum.get_member(constants.InputMediaType, media_type, media_type)
+        self.media: Union[str, InputFile, Animation, Audio, Document, PhotoSize, Video] = media
+        self.caption: Optional[str] = caption
+        self.caption_entities: Tuple[MessageEntity, ...] = parse_sequence_arg(caption_entities)
+        self.parse_mode: ODVInput[str] = parse_mode
 
         self._freeze()
 
     @staticmethod
-    def _parse_thumb_input(thumb: Optional[FileInput]) -> Optional[Union[str, InputFile]]:
+    def _parse_thumbnail_input(thumbnail: Optional[FileInput]) -> Optional[Union[str, InputFile]]:
         # We use local_mode=True because we don't have access to the actual setting and want
         # things to work in local mode.
         return (
-            parse_file_input(thumb, attach=True, local_mode=True) if thumb is not None else thumb
+            parse_file_input(thumbnail, attach=True, local_mode=True)
+            if thumbnail is not None
+            else thumbnail
         )
 
 
@@ -121,6 +125,9 @@ class InputMediaAnimation(InputMedia):
 
     .. seealso:: :wiki:`Working with Files and Media <Working-with-Files-and-Media>`
 
+    .. versionchanged:: 20.5
+      |removed_thumb_note|
+
     Args:
         media (:obj:`str` | :term:`file object` | :obj:`bytes` | :class:`pathlib.Path` | \
             :class:`telegram.Animation`): File to send. |fileinputnopath|
@@ -133,11 +140,6 @@ class InputMediaAnimation(InputMedia):
             :obj:`tempfile` module.
 
             .. versionadded:: 13.1
-        thumb (:term:`file object` | :obj:`bytes` | :class:`pathlib.Path` | :obj:`str`, \
-                optional): |thumbdocstringnopath|
-
-            .. versionchanged:: 13.2
-               Accept :obj:`bytes` as input.
         caption (:obj:`str`, optional): Caption of the animation to be sent,
             0-:tg-const:`telegram.constants.MessageLimit.CAPTION_LENGTH` characters
             after entities parsing.
@@ -154,11 +156,14 @@ class InputMediaAnimation(InputMedia):
             with a spoiler animation.
 
             .. versionadded:: 20.0
+        thumbnail (:term:`file object` | :obj:`bytes` | :class:`pathlib.Path` | :obj:`str`, \
+                optional): |thumbdocstringnopath|
+
+            .. versionadded:: 20.2
 
     Attributes:
         type (:obj:`str`): :tg-const:`telegram.constants.InputMediaType.ANIMATION`.
         media (:obj:`str` | :class:`telegram.InputFile`): Animation to send.
-        thumb (:class:`telegram.InputFile`): Optional. |thumbdocstringbase|
         caption (:obj:`str`): Optional. Caption of the animation to be sent,
             0-:tg-const:`telegram.constants.MessageLimit.CAPTION_LENGTH` characters
             after entities parsing.
@@ -176,24 +181,27 @@ class InputMediaAnimation(InputMedia):
             spoiler animation.
 
             .. versionadded:: 20.0
+        thumbnail (:class:`telegram.InputFile`): Optional. |thumbdocstringbase|
+
+            .. versionadded:: 20.2
     """
 
-    __slots__ = ("duration", "height", "thumb", "width", "has_spoiler")
+    __slots__ = ("duration", "has_spoiler", "height", "thumbnail", "width")
 
     def __init__(
         self,
         media: Union[FileInput, Animation],
-        thumb: FileInput = None,
-        caption: str = None,
+        caption: Optional[str] = None,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
-        width: int = None,
-        height: int = None,
-        duration: int = None,
-        caption_entities: Sequence[MessageEntity] = None,
-        filename: str = None,
-        has_spoiler: bool = None,
+        width: Optional[int] = None,
+        height: Optional[int] = None,
+        duration: Optional[int] = None,
+        caption_entities: Optional[Sequence[MessageEntity]] = None,
+        filename: Optional[str] = None,
+        has_spoiler: Optional[bool] = None,
+        thumbnail: Optional[FileInput] = None,
         *,
-        api_kwargs: JSONDict = None,
+        api_kwargs: Optional[JSONDict] = None,
     ):
         if isinstance(media, Animation):
             width = media.width if width is None else width
@@ -214,11 +222,13 @@ class InputMediaAnimation(InputMedia):
             api_kwargs=api_kwargs,
         )
         with self._unfrozen():
-            self.thumb = self._parse_thumb_input(thumb)
-            self.width = width
-            self.height = height
-            self.duration = duration
-            self.has_spoiler = has_spoiler
+            self.thumbnail: Optional[Union[str, InputFile]] = self._parse_thumbnail_input(
+                thumbnail
+            )
+            self.width: Optional[int] = width
+            self.height: Optional[int] = height
+            self.duration: Optional[int] = duration
+            self.has_spoiler: Optional[bool] = has_spoiler
 
 
 class InputMediaPhoto(InputMedia):
@@ -275,13 +285,13 @@ class InputMediaPhoto(InputMedia):
     def __init__(
         self,
         media: Union[FileInput, PhotoSize],
-        caption: str = None,
+        caption: Optional[str] = None,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
-        caption_entities: Sequence[MessageEntity] = None,
-        filename: str = None,
-        has_spoiler: bool = None,
+        caption_entities: Optional[Sequence[MessageEntity]] = None,
+        filename: Optional[str] = None,
+        has_spoiler: Optional[bool] = None,
         *,
-        api_kwargs: JSONDict = None,
+        api_kwargs: Optional[JSONDict] = None,
     ):
         # We use local_mode=True because we don't have access to the actual setting and want
         # things to work in local mode.
@@ -296,7 +306,7 @@ class InputMediaPhoto(InputMedia):
         )
 
         with self._unfrozen():
-            self.has_spoiler = has_spoiler
+            self.has_spoiler: Optional[bool] = has_spoiler
 
 
 class InputMediaVideo(InputMedia):
@@ -308,9 +318,12 @@ class InputMediaVideo(InputMedia):
         *  When using a :class:`telegram.Video` for the :attr:`media` attribute, it will take the
            width, height and duration from that video, unless otherwise specified with the optional
            arguments.
-        *  :paramref:`thumb` will be ignored for small video files, for which Telegram can easily
-           generate thumbnails. However, this behaviour is undocumented and might be changed
-           by Telegram.
+        *  :paramref:`thumbnail` will be ignored for small video files, for which Telegram can
+            easily generate thumbnails. However, this behaviour is undocumented and might be
+            changed by Telegram.
+
+    .. versionchanged:: 20.5
+      |removed_thumb_note|
 
     Args:
         media (:obj:`str` | :term:`file object` | :obj:`bytes` | :class:`pathlib.Path` | \
@@ -338,15 +351,14 @@ class InputMediaVideo(InputMedia):
         duration (:obj:`int`, optional): Video duration in seconds.
         supports_streaming (:obj:`bool`, optional): Pass :obj:`True`, if the uploaded video is
             suitable for streaming.
-        thumb (:term:`file object` | :obj:`bytes` | :class:`pathlib.Path` | :obj:`str`, \
-                optional): |thumbdocstringnopath|
-
-            .. versionchanged:: 13.2
-               Accept :obj:`bytes` as input.
         has_spoiler (:obj:`bool`, optional): Pass :obj:`True`, if the video needs to be covered
             with a spoiler animation.
 
             .. versionadded:: 20.0
+        thumbnail (:term:`file object` | :obj:`bytes` | :class:`pathlib.Path` | :obj:`str`, \
+                optional): |thumbdocstringnopath|
+
+            .. versionadded:: 20.2
 
     Attributes:
         type (:obj:`str`): :tg-const:`telegram.constants.InputMediaType.VIDEO`.
@@ -366,32 +378,40 @@ class InputMediaVideo(InputMedia):
         duration (:obj:`int`): Optional. Video duration in seconds.
         supports_streaming (:obj:`bool`): Optional. :obj:`True`, if the uploaded video is
             suitable for streaming.
-        thumb (:class:`telegram.InputFile`): Optional. |thumbdocstringbase|
         has_spoiler (:obj:`bool`): Optional. :obj:`True`, if the video is covered with a
             spoiler animation.
 
             .. versionadded:: 20.0
+        thumbnail (:class:`telegram.InputFile`): Optional. |thumbdocstringbase|
+
+            .. versionadded:: 20.2
     """
 
-    __slots__ = ("duration", "height", "thumb", "supports_streaming", "width", "has_spoiler")
+    __slots__ = (
+        "duration",
+        "has_spoiler",
+        "height",
+        "supports_streaming",
+        "thumbnail",
+        "width",
+    )
 
     def __init__(
         self,
         media: Union[FileInput, Video],
-        caption: str = None,
-        width: int = None,
-        height: int = None,
-        duration: int = None,
-        supports_streaming: bool = None,
+        caption: Optional[str] = None,
+        width: Optional[int] = None,
+        height: Optional[int] = None,
+        duration: Optional[int] = None,
+        supports_streaming: Optional[bool] = None,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
-        thumb: FileInput = None,
-        caption_entities: Sequence[MessageEntity] = None,
-        filename: str = None,
-        has_spoiler: bool = None,
+        caption_entities: Optional[Sequence[MessageEntity]] = None,
+        filename: Optional[str] = None,
+        has_spoiler: Optional[bool] = None,
+        thumbnail: Optional[FileInput] = None,
         *,
-        api_kwargs: JSONDict = None,
+        api_kwargs: Optional[JSONDict] = None,
     ):
-
         if isinstance(media, Video):
             width = width if width is not None else media.width
             height = height if height is not None else media.height
@@ -411,12 +431,14 @@ class InputMediaVideo(InputMedia):
             api_kwargs=api_kwargs,
         )
         with self._unfrozen():
-            self.width = width
-            self.height = height
-            self.duration = duration
-            self.thumb = self._parse_thumb_input(thumb)
-            self.supports_streaming = supports_streaming
-            self.has_spoiler = has_spoiler
+            self.width: Optional[int] = width
+            self.height: Optional[int] = height
+            self.duration: Optional[int] = duration
+            self.thumbnail: Optional[Union[str, InputFile]] = self._parse_thumbnail_input(
+                thumbnail
+            )
+            self.supports_streaming: Optional[bool] = supports_streaming
+            self.has_spoiler: Optional[bool] = has_spoiler
 
 
 class InputMediaAudio(InputMedia):
@@ -429,6 +451,9 @@ class InputMediaAudio(InputMedia):
         duration, performer and title from that video, unless otherwise specified with the
         optional arguments.
 
+    .. versionchanged:: 20.5
+      |removed_thumb_note|
+
     Args:
         media (:obj:`str` | :term:`file object` | :obj:`bytes` | :class:`pathlib.Path` | \
             :class:`telegram.Audio`): File to send. |fileinputnopath|
@@ -454,11 +479,10 @@ class InputMediaAudio(InputMedia):
         performer (:obj:`str`, optional): Performer of the audio as defined by sender or by audio
             tags.
         title (:obj:`str`, optional): Title of the audio as defined by sender or by audio tags.
-        thumb (:term:`file object` | :obj:`bytes` | :class:`pathlib.Path` | :obj:`str`, \
+        thumbnail (:term:`file object` | :obj:`bytes` | :class:`pathlib.Path` | :obj:`str`, \
                 optional): |thumbdocstringnopath|
 
-            .. versionchanged:: 13.2
-               Accept :obj:`bytes` as input.
+            .. versionadded:: 20.2
 
     Attributes:
         type (:obj:`str`): :tg-const:`telegram.constants.InputMediaType.AUDIO`.
@@ -477,25 +501,27 @@ class InputMediaAudio(InputMedia):
         performer (:obj:`str`): Optional. Performer of the audio as defined by sender or by audio
             tags.
         title (:obj:`str`): Optional. Title of the audio as defined by sender or by audio tags.
-        thumb (:class:`telegram.InputFile`): Optional. |thumbdocstringbase|
+        thumbnail (:class:`telegram.InputFile`): Optional. |thumbdocstringbase|
+
+            .. versionadded:: 20.2
 
     """
 
-    __slots__ = ("duration", "performer", "thumb", "title")
+    __slots__ = ("duration", "performer", "thumbnail", "title")
 
     def __init__(
         self,
         media: Union[FileInput, Audio],
-        thumb: FileInput = None,
-        caption: str = None,
+        caption: Optional[str] = None,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
-        duration: int = None,
-        performer: str = None,
-        title: str = None,
-        caption_entities: Sequence[MessageEntity] = None,
-        filename: str = None,
+        duration: Optional[int] = None,
+        performer: Optional[str] = None,
+        title: Optional[str] = None,
+        caption_entities: Optional[Sequence[MessageEntity]] = None,
+        filename: Optional[str] = None,
+        thumbnail: Optional[FileInput] = None,
         *,
-        api_kwargs: JSONDict = None,
+        api_kwargs: Optional[JSONDict] = None,
     ):
         if isinstance(media, Audio):
             duration = media.duration if duration is None else duration
@@ -516,10 +542,12 @@ class InputMediaAudio(InputMedia):
             api_kwargs=api_kwargs,
         )
         with self._unfrozen():
-            self.thumb = self._parse_thumb_input(thumb)
-            self.duration = duration
-            self.title = title
-            self.performer = performer
+            self.thumbnail: Optional[Union[str, InputFile]] = self._parse_thumbnail_input(
+                thumbnail
+            )
+            self.duration: Optional[int] = duration
+            self.title: Optional[str] = title
+            self.performer: Optional[str] = performer
 
 
 class InputMediaDocument(InputMedia):
@@ -527,6 +555,9 @@ class InputMediaDocument(InputMedia):
 
     .. seealso:: :wiki:`Working with Files and Media <Working-with-Files-and-Media>`
 
+    .. versionchanged:: 20.5
+      |removed_thumb_note|
+
     Args:
         media (:obj:`str` | :term:`file object` | :obj:`bytes` | :class:`pathlib.Path` | \
             :class:`telegram.Document`): File to send. |fileinputnopath|
@@ -548,14 +579,13 @@ class InputMediaDocument(InputMedia):
             .. versionchanged:: 20.0
                 |sequenceclassargs|
 
-        thumb (:term:`file object` | :obj:`bytes` | :class:`pathlib.Path` | :obj:`str`, \
-                optional): |thumbdocstringnopath|
-
-            .. versionchanged:: 13.2
-               Accept :obj:`bytes` as input.
         disable_content_type_detection (:obj:`bool`, optional): Disables automatic server-side
             content type detection for files uploaded using multipart/form-data. Always
             :obj:`True`, if the document is sent as part of an album.
+        thumbnail (:term:`file object` | :obj:`bytes` | :class:`pathlib.Path` | :obj:`str`, \
+                optional): |thumbdocstringnopath|
+
+            .. versionadded:: 20.2
 
     Attributes:
         type (:obj:`str`): :tg-const:`telegram.constants.InputMediaType.DOCUMENT`.
@@ -570,30 +600,32 @@ class InputMediaDocument(InputMedia):
 
                 * |tupleclassattrs|
                 * |alwaystuple|
-        thumb (:class:`telegram.InputFile`): Optional. |thumbdocstringbase|
         disable_content_type_detection (:obj:`bool`): Optional. Disables automatic server-side
             content type detection for files uploaded using multipart/form-data. Always
             :obj:`True`, if the document is sent as part of an album.
+        thumbnail (:class:`telegram.InputFile`): Optional. |thumbdocstringbase|
 
+            .. versionadded:: 20.2
     """
 
-    __slots__ = ("disable_content_type_detection", "thumb")
+    __slots__ = ("disable_content_type_detection", "thumbnail")
 
     def __init__(
         self,
         media: Union[FileInput, Document],
-        thumb: FileInput = None,
-        caption: str = None,
+        caption: Optional[str] = None,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
-        disable_content_type_detection: bool = None,
-        caption_entities: Sequence[MessageEntity] = None,
-        filename: str = None,
+        disable_content_type_detection: Optional[bool] = None,
+        caption_entities: Optional[Sequence[MessageEntity]] = None,
+        filename: Optional[str] = None,
+        thumbnail: Optional[FileInput] = None,
         *,
-        api_kwargs: JSONDict = None,
+        api_kwargs: Optional[JSONDict] = None,
     ):
         # We use local_mode=True because we don't have access to the actual setting and want
         # things to work in local mode.
         media = parse_file_input(media, Document, filename=filename, attach=True, local_mode=True)
+
         super().__init__(
             InputMediaType.DOCUMENT,
             media,
@@ -603,5 +635,7 @@ class InputMediaDocument(InputMedia):
             api_kwargs=api_kwargs,
         )
         with self._unfrozen():
-            self.thumb = self._parse_thumb_input(thumb)
-            self.disable_content_type_detection = disable_content_type_detection
+            self.thumbnail: Optional[Union[str, InputFile]] = self._parse_thumbnail_input(
+                thumbnail
+            )
+            self.disable_content_type_detection: Optional[bool] = disable_content_type_detection
