@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,6 +18,8 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Telegram PhotoSize."""
 
+from typing import Optional
+
 from telegram._files._basemedium import _BaseMedium
 from telegram._utils.types import JSONDict
 
@@ -51,7 +53,7 @@ class PhotoSize(_BaseMedium):
 
     """
 
-    __slots__ = ("width", "height")
+    __slots__ = ("height", "width")
 
     def __init__(
         self,
@@ -59,9 +61,9 @@ class PhotoSize(_BaseMedium):
         file_unique_id: str,
         width: int,
         height: int,
-        file_size: int = None,
+        file_size: Optional[int] = None,
         *,
-        api_kwargs: JSONDict = None,
+        api_kwargs: Optional[JSONDict] = None,
     ):
         super().__init__(
             file_id=file_id,
@@ -71,5 +73,5 @@ class PhotoSize(_BaseMedium):
         )
         with self._unfrozen():
             # Required
-            self.width = width
-            self.height = height
+            self.width: int = width
+            self.height: int = height
