@@ -45,8 +45,8 @@ class ForceReply(TelegramObject):
 
             1) Users that are @mentioned in the :attr:`~telegram.Message.text` of the
                :class:`telegram.Message` object.
-            2) If the bot's message is a reply (has ``reply_to_message_id``), sender of the
-               original message.
+            2) If the bot's message is a reply to a message in the same chat and forum topic,
+               sender of the original message.
 
         input_field_placeholder (:obj:`str`, optional): The placeholder to be shown in the input
             field when the reply is active;
@@ -63,8 +63,8 @@ class ForceReply(TelegramObject):
 
             1) Users that are @mentioned in the :attr:`~telegram.Message.text` of the
                :class:`telegram.Message` object.
-            2) If the bot's message is a reply (has ``reply_to_message_id``), sender of the
-               original message.
+            2) If the bot's message is a reply to a message in the same chat and forum topic,
+                sender of the original message.
         input_field_placeholder (:obj:`str`): Optional. The placeholder to be shown in the input
             field when the reply is active;
             :tg-const:`telegram.ForceReply.MIN_INPUT_FIELD_PLACEHOLDER`-
@@ -75,7 +75,7 @@ class ForceReply(TelegramObject):
 
     """
 
-    __slots__ = ("selective", "force_reply", "input_field_placeholder")
+    __slots__ = ("force_reply", "input_field_placeholder", "selective")
 
     def __init__(
         self,
