@@ -65,14 +65,14 @@ class InputVenueMessageContent(InputMessageContent):
     """
 
     __slots__ = (
-        "longitude",
-        "google_place_type",
-        "title",
         "address",
         "foursquare_id",
         "foursquare_type",
         "google_place_id",
+        "google_place_type",
         "latitude",
+        "longitude",
+        "title",
     )
 
     def __init__(
@@ -81,12 +81,12 @@ class InputVenueMessageContent(InputMessageContent):
         longitude: float,
         title: str,
         address: str,
-        foursquare_id: str = None,
-        foursquare_type: str = None,
-        google_place_id: str = None,
-        google_place_type: str = None,
+        foursquare_id: Optional[str] = None,
+        foursquare_type: Optional[str] = None,
+        google_place_id: Optional[str] = None,
+        google_place_type: Optional[str] = None,
         *,
-        api_kwargs: JSONDict = None,
+        api_kwargs: Optional[JSONDict] = None,
     ):
         super().__init__(api_kwargs=api_kwargs)
         with self._unfrozen():
