@@ -43,6 +43,7 @@ from typing import (
 )
 
 from telegram._utils.datetime import to_timestamp
+from telegram._utils.defaultvalue import DefaultValue
 from telegram._utils.types import JSONDict
 from telegram._utils.warnings import warn
 
@@ -89,7 +90,7 @@ class TelegramObject:
 
     """
 
-    __slots__ = ("_id_attrs", "_bot", "_frozen", "api_kwargs")
+    __slots__ = ("_bot", "_frozen", "_id_attrs", "api_kwargs")
 
     # Used to cache the names of the parameters of the __init__ method of the class
     # Must be a private attribute to avoid name clashes between subclasses
@@ -106,47 +107,57 @@ class TelegramObject:
         # classes than classes with arguments.
         self._frozen: bool = False
         self._id_attrs: Tuple[object, ...] = ()
-        self._bot: Optional["Bot"] = None
+        self._bot: Optional[Bot] = None
         # We don't do anything with api_kwargs here - see docstring of _apply_api_kwargs
         self.api_kwargs: Mapping[str, Any] = MappingProxyType(api_kwargs or {})
 
-    def _freeze(self) -> None:
-        self._frozen = True
+    def __eq__(self, other: object) -> bool:
+        """Compares this object with :paramref:`other` in terms of equality.
+        If this object and :paramref:`other` are `not` objects of the same class,
+        this comparison will fall back to Python's default implementation of :meth:`object.__eq__`.
+        Otherwise, both objects may be compared in terms of equality, if the corresponding
+        subclass of :class:`TelegramObject` has defined a set of attributes to compare and
+        the objects are considered to be equal, if all of these attributes are equal.
+        If the subclass has not defined a set of attributes to compare, a warning will be issued.
 
-    def _unfreeze(self) -> None:
-        self._frozen = False
+        Tip:
+            If instances of a class in the :mod:`telegram` module are comparable in terms of
+            equality, the documentation of the class will state the attributes that will be used
+            for this comparison.
 
-    @contextmanager
-    def _unfrozen(self: Tele_co) -> Iterator[Tele_co]:
-        """Context manager to temporarily unfreeze the object. For internal use only.
+        Args:
+            other (:obj:`object`): The object to compare with.
+
+        Returns:
+            :obj:`bool`
 
-        Note:
-            with to._unfrozen() as other_to:
-                assert to is other_to
         """
-        self._unfreeze()
-        yield self
-        self._freeze()
+        if isinstance(other, self.__class__):
+            if not self._id_attrs:
+                warn(
+                    f"Objects of type {self.__class__.__name__} can not be meaningfully tested for"
+                    " equivalence.",
+                    stacklevel=2,
+                )
+            if not other._id_attrs:
+                warn(
+                    f"Objects of type {other.__class__.__name__} can not be meaningfully tested"
+                    " for equivalence.",
+                    stacklevel=2,
+                )
+            return self._id_attrs == other._id_attrs
+        return super().__eq__(other)
 
-    def _apply_api_kwargs(self, api_kwargs: JSONDict) -> None:
-        """Loops through the api kwargs and for every key that exists as attribute of the
-        object (and is None), it moves the value from `api_kwargs` to the attribute.
-        *Edits `api_kwargs` in place!*
+    def __hash__(self) -> int:
+        """Builds a hash value for this object such that the hash of two objects is equal if and
+        only if the objects are equal in terms of :meth:`__eq__`.
 
-        This method is currently only called in the unpickling process, i.e. not on "normal" init.
-        This is because
-        * automating this is tricky to get right: It should be called at the *end* of the __init__,
-          preferably only once at the end of the __init__ of the last child class. This could be
-          done via __init_subclass__, but it's hard to not destroy the signature of __init__ in the
-          process.
-        * calling it manually in every __init__ is tedious
-        * There probably is no use case for it anyway. If you manually initialize a TO subclass,
-          then you can pass everything as proper argument.
+        Returns:
+            :obj:`int`
         """
-        # we convert to list to ensure that the list doesn't change length while we loop
-        for key in list(api_kwargs.keys()):
-            if getattr(self, key, True) is None:
-                setattr(self, key, api_kwargs.pop(key))
+        if self._id_attrs:
+            return hash((self.__class__, self._id_attrs))
+        return super().__hash__()
 
     def __setattr__(self, key: str, value: object) -> None:
         """Overrides :meth:`object.__setattr__` to prevent the overriding of attributes.
@@ -261,7 +272,9 @@ class TelegramObject:
         Returns:
             state (Dict[:obj:`str`, :obj:`object`]): The state of the object.
         """
-        out = self._get_attrs(include_private=True, recursive=False, remove_bot=True)
+        out = self._get_attrs(
+            include_private=True, recursive=False, remove_bot=True, convert_default_vault=False
+        )
         # MappingProxyType is not pickable, so we convert it to a dict and revert in
         # __setstate__
         out["api_kwargs"] = dict(self.api_kwargs)
@@ -364,65 +377,6 @@ class TelegramObject:
         self.set_bot(bot)
         return result
 
-    def _get_attrs_names(self, include_private: bool) -> Iterator[str]:
-        """
-        Returns the names of the attributes of this object. This is used to determine which
-        attributes should be serialized when pickling the object.
-
-        Args:
-            include_private (:obj:`bool`): Whether to include private attributes.
-
-        Returns:
-            Iterator[:obj:`str`]: An iterator over the names of the attributes of this object.
-        """
-        # We want to get all attributes for the class, using self.__slots__ only includes the
-        # attributes used by that class itself, and not its superclass(es). Hence, we get its MRO
-        # and then get their attributes. The `[:-1]` slice excludes the `object` class
-        all_slots = (s for c in self.__class__.__mro__[:-1] for s in c.__slots__)  # type: ignore
-        # chain the class's slots with the user defined subclass __dict__ (class has no slots)
-        all_attrs = (
-            chain(all_slots, self.__dict__.keys()) if hasattr(self, "__dict__") else all_slots
-        )
-
-        if include_private:
-            return all_attrs
-        return (attr for attr in all_attrs if not attr.startswith("_"))
-
-    def _get_attrs(
-        self,
-        include_private: bool = False,
-        recursive: bool = False,
-        remove_bot: bool = False,
-    ) -> Dict[str, Union[str, object]]:
-        """This method is used for obtaining the attributes of the object.
-
-        Args:
-            include_private (:obj:`bool`): Whether the result should include private variables.
-            recursive (:obj:`bool`): If :obj:`True`, will convert any ``TelegramObjects`` (if
-                found) in the attributes to a dictionary. Else, preserves it as an object itself.
-            remove_bot (:obj:`bool`): Whether the bot should be included in the result.
-
-        Returns:
-            :obj:`dict`: A dict where the keys are attribute names and values are their values.
-        """
-        data = {}
-
-        for key in self._get_attrs_names(include_private=include_private):
-            value = getattr(self, key, None)
-            if value is not None:
-                if recursive and hasattr(value, "to_dict"):
-                    data[key] = value.to_dict(recursive=True)
-                else:
-                    data[key] = value
-            elif not recursive:
-                data[key] = value
-
-        if recursive and data.get("from_user"):
-            data["from"] = data.pop("from_user", None)
-        if remove_bot:
-            data.pop("_bot", None)
-        return data
-
     @staticmethod
     def _parse_data(data: Optional[JSONDict]) -> Optional[JSONDict]:
         """Should be called by subclasses that override de_json to ensure that the input
@@ -431,20 +385,6 @@ class TelegramObject:
         """
         return None if data is None else data.copy()
 
-    @classmethod
-    def de_json(cls: Type[Tele_co], data: Optional[JSONDict], bot: "Bot") -> Optional[Tele_co]:
-        """Converts JSON data to a Telegram object.
-
-        Args:
-            data (Dict[:obj:`str`, ...]): The JSON data.
-            bot (:class:`telegram.Bot`): The bot associated with this object.
-
-        Returns:
-            The Telegram object.
-
-        """
-        return cls._de_json(data=data, bot=bot)
-
     @classmethod
     def _de_json(
         cls: Type[Tele_co],
@@ -477,6 +417,20 @@ class TelegramObject:
         obj.set_bot(bot=bot)
         return obj
 
+    @classmethod
+    def de_json(cls: Type[Tele_co], data: Optional[JSONDict], bot: "Bot") -> Optional[Tele_co]:
+        """Converts JSON data to a Telegram object.
+
+        Args:
+            data (Dict[:obj:`str`, ...]): The JSON data.
+            bot (:class:`telegram.Bot`): The bot associated with this object.
+
+        Returns:
+            The Telegram object.
+
+        """
+        return cls._de_json(data=data, bot=bot)
+
     @classmethod
     def de_list(
         cls: Type[Tele_co], data: Optional[List[JSONDict]], bot: "Bot"
@@ -501,6 +455,113 @@ class TelegramObject:
 
         return tuple(obj for obj in (cls.de_json(d, bot) for d in data) if obj is not None)
 
+    @contextmanager
+    def _unfrozen(self: Tele_co) -> Iterator[Tele_co]:
+        """Context manager to temporarily unfreeze the object. For internal use only.
+
+        Note:
+            with to._unfrozen() as other_to:
+                assert to is other_to
+        """
+        self._unfreeze()
+        yield self
+        self._freeze()
+
+    def _freeze(self) -> None:
+        self._frozen = True
+
+    def _unfreeze(self) -> None:
+        self._frozen = False
+
+    def _apply_api_kwargs(self, api_kwargs: JSONDict) -> None:
+        """Loops through the api kwargs and for every key that exists as attribute of the
+        object (and is None), it moves the value from `api_kwargs` to the attribute.
+        *Edits `api_kwargs` in place!*
+
+        This method is currently only called in the unpickling process, i.e. not on "normal" init.
+        This is because
+        * automating this is tricky to get right: It should be called at the *end* of the __init__,
+          preferably only once at the end of the __init__ of the last child class. This could be
+          done via __init_subclass__, but it's hard to not destroy the signature of __init__ in the
+          process.
+        * calling it manually in every __init__ is tedious
+        * There probably is no use case for it anyway. If you manually initialize a TO subclass,
+          then you can pass everything as proper argument.
+        """
+        # we convert to list to ensure that the list doesn't change length while we loop
+        for key in list(api_kwargs.keys()):
+            if getattr(self, key, True) is None:
+                setattr(self, key, api_kwargs.pop(key))
+
+    def _get_attrs_names(self, include_private: bool) -> Iterator[str]:
+        """
+        Returns the names of the attributes of this object. This is used to determine which
+        attributes should be serialized when pickling the object.
+
+        Args:
+            include_private (:obj:`bool`): Whether to include private attributes.
+
+        Returns:
+            Iterator[:obj:`str`]: An iterator over the names of the attributes of this object.
+        """
+        # We want to get all attributes for the class, using self.__slots__ only includes the
+        # attributes used by that class itself, and not its superclass(es). Hence, we get its MRO
+        # and then get their attributes. The `[:-1]` slice excludes the `object` class
+        all_slots = (s for c in self.__class__.__mro__[:-1] for s in c.__slots__)  # type: ignore
+        # chain the class's slots with the user defined subclass __dict__ (class has no slots)
+        all_attrs = (
+            chain(all_slots, self.__dict__.keys()) if hasattr(self, "__dict__") else all_slots
+        )
+
+        if include_private:
+            return all_attrs
+        return (attr for attr in all_attrs if not attr.startswith("_"))
+
+    def _get_attrs(
+        self,
+        include_private: bool = False,
+        recursive: bool = False,
+        remove_bot: bool = False,
+        convert_default_vault: bool = True,
+    ) -> Dict[str, Union[str, object]]:
+        """This method is used for obtaining the attributes of the object.
+
+        Args:
+            include_private (:obj:`bool`): Whether the result should include private variables.
+            recursive (:obj:`bool`): If :obj:`True`, will convert any ``TelegramObjects`` (if
+                found) in the attributes to a dictionary. Else, preserves it as an object itself.
+            remove_bot (:obj:`bool`): Whether the bot should be included in the result.
+            convert_default_vault (:obj:`bool`): Whether :class:`telegram.DefaultValue` should be
+                converted to its true value. This is necessary when converting to a dictionary for
+                end users since DefaultValue is used in some classes that work with
+                `tg.ext.defaults` (like `LinkPreviewOptions`)
+
+        Returns:
+            :obj:`dict`: A dict where the keys are attribute names and values are their values.
+        """
+        data = {}
+
+        for key in self._get_attrs_names(include_private=include_private):
+            value = (
+                DefaultValue.get_value(getattr(self, key, None))
+                if convert_default_vault
+                else getattr(self, key, None)
+            )
+
+            if value is not None:
+                if recursive and hasattr(value, "to_dict"):
+                    data[key] = value.to_dict(recursive=True)
+                else:
+                    data[key] = value
+            elif not recursive:
+                data[key] = value
+
+        if recursive and data.get("from_user"):
+            data["from"] = data.pop("from_user", None)
+        if remove_bot:
+            data.pop("_bot", None)
+        return data
+
     def to_json(self) -> str:
         """Gives a JSON representation of object.
 
@@ -596,51 +657,3 @@ class TelegramObject:
             bot (:class:`telegram.Bot` | :obj:`None`): The bot instance.
         """
         self._bot = bot
-
-    def __eq__(self, other: object) -> bool:
-        """Compares this object with :paramref:`other` in terms of equality.
-        If this object and :paramref:`other` are `not` objects of the same class,
-        this comparison will fall back to Python's default implementation of :meth:`object.__eq__`.
-        Otherwise, both objects may be compared in terms of equality, if the corresponding
-        subclass of :class:`TelegramObject` has defined a set of attributes to compare and
-        the objects are considered to be equal, if all of these attributes are equal.
-        If the subclass has not defined a set of attributes to compare, a warning will be issued.
-
-        Tip:
-            If instances of a class in the :mod:`telegram` module are comparable in terms of
-            equality, the documentation of the class will state the attributes that will be used
-            for this comparison.
-
-        Args:
-            other (:obj:`object`): The object to compare with.
-
-        Returns:
-            :obj:`bool`
-
-        """
-        if isinstance(other, self.__class__):
-            if not self._id_attrs:
-                warn(
-                    f"Objects of type {self.__class__.__name__} can not be meaningfully tested for"
-                    " equivalence.",
-                    stacklevel=2,
-                )
-            if not other._id_attrs:
-                warn(
-                    f"Objects of type {other.__class__.__name__} can not be meaningfully tested"
-                    " for equivalence.",
-                    stacklevel=2,
-                )
-            return self._id_attrs == other._id_attrs
-        return super().__eq__(other)
-
-    def __hash__(self) -> int:
-        """Builds a hash value for this object such that the hash of two objects is equal if and
-        only if the objects are equal in terms of :meth:`__eq__`.
-
-        Returns:
-            :obj:`int`
-        """
-        if self._id_attrs:
-            return hash((self.__class__, self._id_attrs))
-        return super().__hash__()
