@@ -40,13 +40,11 @@ _T = TypeVar("_T", bound=Union[bytes, "InputFile", str, Path, None])
 
 
 @overload
-def load_file(obj: IO[bytes]) -> Tuple[Optional[str], bytes]:
-    ...
+def load_file(obj: IO[bytes]) -> Tuple[Optional[str], bytes]: ...
 
 
 @overload
-def load_file(obj: _T) -> Tuple[None, _T]:
-    ...
+def load_file(obj: _T) -> Tuple[None, _T]: ...
 
 
 def load_file(
@@ -90,8 +88,8 @@ def is_local_file(obj: Optional[FilePathInput]) -> bool:
 
 def parse_file_input(  # pylint: disable=too-many-return-statements
     file_input: Union[FileInput, "TelegramObject"],
-    tg_type: Type["TelegramObject"] = None,
-    filename: str = None,
+    tg_type: Optional[Type["TelegramObject"]] = None,
+    filename: Optional[str] = None,
     attach: bool = False,
     local_mode: bool = False,
 ) -> Union[str, "InputFile", Any]:
