@@ -136,21 +136,22 @@ class ApplicationBuilder(Generic[BT, CCT, UD, CD, BD, JQ]):
         "_base_file_url",
         "_base_url",
         "_bot",
-        "_update_processor",
         "_connect_timeout",
         "_connection_pool_size",
         "_context_types",
         "_defaults",
         "_get_updates_connect_timeout",
         "_get_updates_connection_pool_size",
+        "_get_updates_http_version",
         "_get_updates_pool_timeout",
         "_get_updates_proxy",
         "_get_updates_read_timeout",
         "_get_updates_request",
         "_get_updates_socket_options",
         "_get_updates_write_timeout",
-        "_get_updates_http_version",
+        "_http_version",
         "_job_queue",
+        "_local_mode",
         "_persistence",
         "_pool_timeout",
         "_post_init",
@@ -164,11 +165,10 @@ class ApplicationBuilder(Generic[BT, CCT, UD, CD, BD, JQ]):
         "_request",
         "_socket_options",
         "_token",
+        "_update_processor",
         "_update_queue",
         "_updater",
         "_write_timeout",
-        "_local_mode",
-        "_http_version",
     )
 
     def __init__(self: "InitApplicationBuilder"):
@@ -272,7 +272,7 @@ class ApplicationBuilder(Generic[BT, CCT, UD, CD, BD, JQ]):
             arbitrary_callback_data=DefaultValue.get_value(self._arbitrary_callback_data),
             request=self._build_request(get_updates=False),
             get_updates_request=self._build_request(get_updates=True),
-            rate_limiter=DefaultValue.get_value(self._rate_limiter),  # type: ignore[arg-type]
+            rate_limiter=DefaultValue.get_value(self._rate_limiter),
             local_mode=DefaultValue.get_value(self._local_mode),
         )
 
@@ -317,7 +317,7 @@ class ApplicationBuilder(Generic[BT, CCT, UD, CD, BD, JQ]):
 
         application: Application[
             BT, CCT, UD, CD, BD, JQ
-        ] = DefaultValue.get_value(  # type: ignore[operator] # pylint: disable=not-callable
+        ] = DefaultValue.get_value(  # pylint: disable=not-callable
             self._application_class
         )(
             bot=bot,
@@ -325,7 +325,7 @@ class ApplicationBuilder(Generic[BT, CCT, UD, CD, BD, JQ]):
             updater=updater,
             update_processor=self._update_processor,
             job_queue=job_queue,
-            persistence=persistence,  # type: ignore[arg-type]
+            persistence=persistence,
             context_types=DefaultValue.get_value(self._context_types),
             post_init=self._post_init,
             post_shutdown=self._post_shutdown,
@@ -334,12 +334,12 @@ class ApplicationBuilder(Generic[BT, CCT, UD, CD, BD, JQ]):
         )
 
         if job_queue is not None:
-            job_queue.set_application(application)  # type: ignore[arg-type, union-attr]
+            job_queue.set_application(application)  # type: ignore[arg-type]
 
         if persistence is not None:
             # This raises an exception if persistence.store_data.callback_data is True
             # but self.bot is not an instance of ExtBot - so no need to check that later on
-            persistence.set_bot(bot)  # type: ignore[union-attr]
+            persistence.set_bot(bot)
 
         return application
 
