@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -25,7 +25,7 @@ from telegram.ext._extbot import ExtBot
 from telegram.ext._utils.types import BD, CD, UD, CDCData, ConversationDict, ConversationKey
 
 
-class PersistenceInput(NamedTuple):  # skipcq: PYL-E0239
+class PersistenceInput(NamedTuple):
     """Convenience wrapper to group boolean input for the :paramref:`~BasePersistence.store_data`
     parameter for :class:`BasePersistence`.
 
@@ -121,9 +121,9 @@ class BasePersistence(Generic[UD, CD, BD], ABC):
           handled by the specific implementation - see above note.
 
     Args:
-        store_data (:class:`PersistenceInput`, optional): Specifies which kinds of data will be
-            saved by this persistence instance. By default, all available kinds of data will be
-            saved.
+        store_data (:class:`~telegram.ext.PersistenceInput`, optional): Specifies which kinds of
+            data will be saved by this persistence instance. By default, all available kinds of
+            data will be saved.
         update_interval (:obj:`int` | :obj:`float`, optional): The
             :class:`~telegram.ext.Application` will update
             the persistence in regular intervals. This parameter specifies the time (in seconds) to
@@ -132,24 +132,24 @@ class BasePersistence(Generic[UD, CD, BD], ABC):
 
             .. versionadded:: 20.0
     Attributes:
-        store_data (:class:`PersistenceInput`): Specifies which kinds of data will be saved by this
-            persistence instance.
+        store_data (:class:`~telegram.ext.PersistenceInput`): Specifies which kinds of data will
+            be saved by this persistence instance.
         bot (:class:`telegram.Bot`): The bot associated with the persistence.
     """
 
     __slots__ = (
+        "_update_interval",
         "bot",
         "store_data",
-        "_update_interval",
     )
 
     def __init__(
         self,
-        store_data: PersistenceInput = None,
+        store_data: Optional[PersistenceInput] = None,
         update_interval: float = 60,
     ):
-        self.store_data = store_data or PersistenceInput()
-        self._update_interval = update_interval
+        self.store_data: PersistenceInput = store_data or PersistenceInput()
+        self._update_interval: float = update_interval
 
         self.bot: Bot = None  # type: ignore[assignment]
 
@@ -357,6 +357,11 @@ class BasePersistence(Generic[UD, CD, BD], ABC):
         :attr:`~telegram.ext.Application.user_data` to a callback. Can be used to update data
         stored in :attr:`~telegram.ext.Application.user_data` from an external source.
 
+        Warning:
+            When using :meth:`~telegram.ext.ApplicationBuilder.concurrent_updates`, this method
+            may be called while a handler callback is still running. This might lead to race
+            conditions.
+
         .. versionadded:: 13.6
 
         .. versionchanged:: 20.0
@@ -375,6 +380,11 @@ class BasePersistence(Generic[UD, CD, BD], ABC):
         :attr:`~telegram.ext.Application.chat_data` to a callback. Can be used to update data
         stored in :attr:`~telegram.ext.Application.chat_data` from an external source.
 
+        Warning:
+            When using :meth:`~telegram.ext.ApplicationBuilder.concurrent_updates`, this method
+            may be called while a handler callback is still running. This might lead to race
+            conditions.
+
         .. versionadded:: 13.6
 
         .. versionchanged:: 20.0
@@ -393,6 +403,11 @@ class BasePersistence(Generic[UD, CD, BD], ABC):
         :attr:`~telegram.ext.Application.bot_data` to a callback. Can be used to update data stored
         in :attr:`~telegram.ext.Application.bot_data` from an external source.
 
+        Warning:
+            When using :meth:`~telegram.ext.ApplicationBuilder.concurrent_updates`, this method
+            may be called while a handler callback is still running. This might lead to race
+            conditions.
+
         .. versionadded:: 13.6
 
         .. versionchanged:: 20.0
