@@ -19,12 +19,14 @@
 """This module contains the DictPersistence class."""
 import json
 from copy import deepcopy
-from typing import Any, Dict, Optional, cast
+from typing import TYPE_CHECKING, Any, Dict, Optional, cast
 
-from telegram._utils.types import JSONDict
 from telegram.ext import BasePersistence, PersistenceInput
 from telegram.ext._utils.types import CDCData, ConversationDict, ConversationKey
 
+if TYPE_CHECKING:
+    from telegram._utils.types import JSONDict
+
 
 class DictPersistence(BasePersistence[Dict[Any, Any], Dict[Any, Any], Dict[Any, Any]]):
     """Using Python's :obj:`dict` and :mod:`json` for making your bot persistent.
@@ -76,21 +78,21 @@ class DictPersistence(BasePersistence[Dict[Any, Any], Dict[Any, Any], Dict[Any,
     """
 
     __slots__ = (
-        "_user_data",
-        "_chat_data",
         "_bot_data",
-        "_callback_data",
-        "_conversations",
-        "_user_data_json",
-        "_chat_data_json",
         "_bot_data_json",
+        "_callback_data",
         "_callback_data_json",
+        "_chat_data",
+        "_chat_data_json",
+        "_conversations",
         "_conversations_json",
+        "_user_data",
+        "_user_data_json",
     )
 
     def __init__(
         self,
-        store_data: PersistenceInput = None,
+        store_data: Optional[PersistenceInput] = None,
         user_data_json: str = "",
         chat_data_json: str = "",
         bot_data_json: str = "",
@@ -468,12 +470,12 @@ class DictPersistence(BasePersistence[Dict[Any, Any], Dict[Any, Any], Dict[Any,
         tmp: Dict[int, Dict[object, object]] = {}
         decoded_data = json.loads(data)
         for user, user_data in decoded_data.items():
-            user = int(user)
-            tmp[user] = {}
+            int_user_id = int(user)
+            tmp[int_user_id] = {}
             for key, value in user_data.items():
                 try:
-                    key = int(key)
+                    _id = int(key)
                 except ValueError:
-                    pass
-                tmp[user][key] = value
+                    _id = key
+                tmp[int_user_id][_id] = value
         return tmp
