@@ -93,7 +93,7 @@ class JobQueue(Generic[CCT]):
 
     """
 
-    __slots__ = ("_application", "scheduler", "_executor")
+    __slots__ = ("_application", "_executor", "scheduler")
     _CRON_MAPPING = ("sun", "mon", "tue", "wed", "thu", "fri", "sat")
 
     def __init__(self) -> None:
@@ -105,7 +105,7 @@ class JobQueue(Generic[CCT]):
 
         self._application: Optional[weakref.ReferenceType[Application]] = None
         self._executor = AsyncIOExecutor()
-        self.scheduler: AsyncIOScheduler = AsyncIOScheduler(**self.scheduler_configuration)
+        self.scheduler: "AsyncIOScheduler" = AsyncIOScheduler(**self.scheduler_configuration)
 
     def __repr__(self) -> str:
         """Give a string representation of the JobQueue in the form ``JobQueue[application=...]``.
@@ -169,16 +169,14 @@ class JobQueue(Generic[CCT]):
         return datetime.datetime.now(self.scheduler.timezone)
 
     @overload
-    def _parse_time_input(self, time: None, shift_day: bool = False) -> None:
-        ...
+    def _parse_time_input(self, time: None, shift_day: bool = False) -> None: ...
 
     @overload
     def _parse_time_input(
         self,
         time: Union[float, datetime.timedelta, datetime.datetime, datetime.time],
         shift_day: bool = False,
-    ) -> datetime.datetime:
-        ...
+    ) -> datetime.datetime: ...
 
     def _parse_time_input(
         self,
@@ -785,13 +783,13 @@ class Job(Generic[CCT]):
     """
 
     __slots__ = (
-        "callback",
-        "data",
-        "name",
-        "_removed",
         "_enabled",
         "_job",
+        "_removed",
+        "callback",
         "chat_id",
+        "data",
+        "name",
         "user_id",
     )
 
@@ -818,9 +816,23 @@ class Job(Generic[CCT]):
         self._removed = False
         self._enabled = False
 
-        self._job = cast("APSJob", None)  # skipcq: PTC-W0052
+        self._job = cast("APSJob", None)
 
     def __getattr__(self, item: str) -> object:
+        """Overrides :py:meth:`object.__getattr__` to get specific attribute of the
+        :class:`telegram.ext.Job` object or of its attribute :class:`apscheduler.job.Job`,
+        if exists.
+
+        Args:
+           item (:obj:`str`): The name of the attribute.
+
+        Returns:
+            :object: The value of the attribute.
+
+        Raises:
+            :exc:`AttributeError`: If the attribute does not exist in both
+                :class:`telegram.ext.Job` and :class:`apscheduler.job.Job` objects.
+        """
         try:
             return getattr(self.job, item)
         except AttributeError as exc:
@@ -829,11 +841,25 @@ class Job(Generic[CCT]):
             ) from exc
 
     def __eq__(self, other: object) -> bool:
+        """Defines equality condition for the :class:`telegram.ext.Job` object.
+        Two objects of this class are considered to be equal if their
+        :class:`id <apscheduler.job.Job>` are equal.
+
+        Returns:
+            :obj:`True` if both objects have :paramref:`id` parameters identical.
+            :obj:`False` otherwise.
+        """
         if isinstance(other, self.__class__):
             return self.id == other.id
         return False
 
     def __hash__(self) -> int:
+        """Builds a hash value for this object such that the hash of two objects is
+        equal if and only if the objects are equal in terms of :meth:`__eq__`.
+
+        Returns:
+            :obj:`int`: The hash value of the object.
+        """
         return hash(self.id)
 
     def __repr__(self) -> str:
