@@ -35,10 +35,10 @@ from typing import (
     Union,
 )
 
-from telegram._utils.defaultvalue import DEFAULT_NONE
+from telegram._utils.defaultvalue import DEFAULT_80, DEFAULT_IP, DEFAULT_NONE, DefaultValue
 from telegram._utils.logging import get_logger
 from telegram._utils.repr import build_repr_with_selected_attrs
-from telegram._utils.types import ODVInput
+from telegram._utils.types import DVType, ODVInput
 from telegram.error import InvalidToken, RetryAfter, TelegramError, TimedOut
 
 try:
@@ -78,6 +78,8 @@ class Updater(AsyncContextManager["Updater"]):
         finally:
             await updater.shutdown()
 
+    .. seealso:: :meth:`__aenter__` and :meth:`__aexit__`.
+
     .. seealso:: :wiki:`Architecture Overview <Architecture>`,
         :wiki:`Builder Pattern <Builder-Pattern>`
 
@@ -99,14 +101,14 @@ class Updater(AsyncContextManager["Updater"]):
     """
 
     __slots__ = (
-        "bot",
-        "update_queue",
-        "_last_update_id",
-        "_running",
-        "_initialized",
-        "_httpd",
         "__lock",
         "__polling_task",
+        "_httpd",
+        "_initialized",
+        "_last_update_id",
+        "_running",
+        "bot",
+        "update_queue",
     )
 
     def __init__(
@@ -126,7 +128,16 @@ class Updater(AsyncContextManager["Updater"]):
         self.__polling_cleanup_cb: Optional[Callable[[], Coroutine[Any, Any, None]]] = None
 
     async def __aenter__(self: _UpdaterType) -> _UpdaterType:  # noqa: PYI019
-        """Simple context manager which initializes the Updater."""
+        """
+        |async_context_manager| :meth:`initializes <initialize>` the Updater.
+
+        Returns:
+            The initialized Updater instance.
+
+        Raises:
+            :exc:`Exception`: If an exception is raised during initialization, :meth:`shutdown`
+                is called in this case.
+        """
         try:
             await self.initialize()
             return self
@@ -140,7 +151,7 @@ class Updater(AsyncContextManager["Updater"]):
         exc_val: Optional[BaseException],
         exc_tb: Optional[TracebackType],
     ) -> None:
-        """Shutdown the Updater from the context manager."""
+        """|async_context_manager| :meth:`shuts down <shutdown>` the Updater."""
         # Make sure not to return `True` so that exceptions are not suppressed
         # https://docs.python.org/3/reference/datamodel.html?#object.__aexit__
         await self.shutdown()
@@ -200,7 +211,7 @@ class Updater(AsyncContextManager["Updater"]):
         poll_interval: float = 0.0,
         timeout: int = 10,
         bootstrap_retries: int = -1,
-        read_timeout: float = 2,
+        read_timeout: ODVInput[float] = DEFAULT_NONE,
         write_timeout: ODVInput[float] = DEFAULT_NONE,
         connect_timeout: ODVInput[float] = DEFAULT_NONE,
         pool_timeout: ODVInput[float] = DEFAULT_NONE,
@@ -225,16 +236,40 @@ class Updater(AsyncContextManager["Updater"]):
                 *   0 - no retries
                 * > 0 - retry up to X times
             read_timeout (:obj:`float`, optional): Value to pass to
-                :paramref:`telegram.Bot.get_updates.read_timeout`. Defaults to ``2``.
+                :paramref:`telegram.Bot.get_updates.read_timeout`. Defaults to
+                :attr:`~telegram.request.BaseRequest.DEFAULT_NONE`.
+
+                .. versionchanged:: 20.7
+                    Defaults to :attr:`~telegram.request.BaseRequest.DEFAULT_NONE` instead of
+                    ``2``.
+                .. deprecated:: 20.7
+                    Deprecated in favor of setting the timeout via
+                    :meth:`telegram.ext.ApplicationBuilder.get_updates_read_timeout` or
+                    :paramref:`telegram.Bot.get_updates_request`.
             write_timeout (:obj:`float` | :obj:`None`, optional): Value to pass to
                 :paramref:`telegram.Bot.get_updates.write_timeout`. Defaults to
                 :attr:`~telegram.request.BaseRequest.DEFAULT_NONE`.
+
+                .. deprecated:: 20.7
+                    Deprecated in favor of setting the timeout via
+                    :meth:`telegram.ext.ApplicationBuilder.get_updates_write_timeout` or
+                    :paramref:`telegram.Bot.get_updates_request`.
             connect_timeout (:obj:`float` | :obj:`None`, optional): Value to pass to
                 :paramref:`telegram.Bot.get_updates.connect_timeout`. Defaults to
                 :attr:`~telegram.request.BaseRequest.DEFAULT_NONE`.
+
+                .. deprecated:: 20.7
+                    Deprecated in favor of setting the timeout via
+                    :meth:`telegram.ext.ApplicationBuilder.get_updates_connect_timeout` or
+                    :paramref:`telegram.Bot.get_updates_request`.
             pool_timeout (:obj:`float` | :obj:`None`, optional): Value to pass to
                 :paramref:`telegram.Bot.get_updates.pool_timeout`. Defaults to
                 :attr:`~telegram.request.BaseRequest.DEFAULT_NONE`.
+
+                .. deprecated:: 20.7
+                    Deprecated in favor of setting the timeout via
+                    :meth:`telegram.ext.ApplicationBuilder.get_updates_pool_timeout` or
+                    :paramref:`telegram.Bot.get_updates_request`.
             allowed_updates (List[:obj:`str`], optional): Passed to
                 :meth:`telegram.Bot.get_updates`.
             drop_pending_updates (:obj:`bool`, optional): Whether to clean any pending updates on
@@ -260,6 +295,10 @@ class Updater(AsyncContextManager["Updater"]):
             :exc:`RuntimeError`: If the updater is already running or was not initialized.
 
         """
+        # We refrain from issuing deprecation warnings for the timeout parameters here, as we
+        # already issue them in `Application`. This means that there are no warnings when using
+        # `Updater` without `Application`, but this is a rather special use case.
+
         if error_callback and asyncio.iscoroutinefunction(error_callback):
             raise TypeError(
                 "The `error_callback` must not be a coroutine function! Use an ordinary function "
@@ -305,7 +344,7 @@ class Updater(AsyncContextManager["Updater"]):
         self,
         poll_interval: float,
         timeout: int,
-        read_timeout: float,
+        read_timeout: ODVInput[float],
         write_timeout: ODVInput[float],
         connect_timeout: ODVInput[float],
         pool_timeout: ODVInput[float],
@@ -390,16 +429,25 @@ class Updater(AsyncContextManager["Updater"]):
             _LOGGER.debug(
                 "Calling `get_updates` one more time to mark all fetched updates as read."
             )
-            await self.bot.get_updates(
-                offset=self._last_update_id,
-                # We don't want to do long polling here!
-                timeout=0,
-                read_timeout=read_timeout,
-                connect_timeout=connect_timeout,
-                write_timeout=write_timeout,
-                pool_timeout=pool_timeout,
-                allowed_updates=allowed_updates,
-            )
+            try:
+                await self.bot.get_updates(
+                    offset=self._last_update_id,
+                    # We don't want to do long polling here!
+                    timeout=0,
+                    read_timeout=read_timeout,
+                    connect_timeout=connect_timeout,
+                    write_timeout=write_timeout,
+                    pool_timeout=pool_timeout,
+                    allowed_updates=allowed_updates,
+                )
+            except TelegramError as exc:
+                _LOGGER.error(
+                    "Error while calling `get_updates` one more time to mark all fetched updates "
+                    "as read: %s. Suppressing error to ensure graceful shutdown. When polling for "
+                    "updates is restarted, updates may be fetched again. Please adjust timeouts "
+                    "via `ApplicationBuilder` or the parameter `get_updates_request` of `Bot`.",
+                    exc_info=exc,
+                )
 
         self.__polling_cleanup_cb = _get_updates_cleanup
 
@@ -408,8 +456,8 @@ class Updater(AsyncContextManager["Updater"]):
 
     async def start_webhook(
         self,
-        listen: str = "127.0.0.1",
-        port: int = 80,
+        listen: DVType[str] = DEFAULT_IP,
+        port: DVType[int] = DEFAULT_80,
         url_path: str = "",
         cert: Optional[Union[str, Path]] = None,
         key: Optional[Union[str, Path]] = None,
@@ -420,6 +468,7 @@ class Updater(AsyncContextManager["Updater"]):
         ip_address: Optional[str] = None,
         max_connections: int = 40,
         secret_token: Optional[str] = None,
+        unix: Optional[Union[str, Path]] = None,
     ) -> "asyncio.Queue[object]":
         """
         Starts a small http server to listen for updates via webhook. If :paramref:`cert`
@@ -488,6 +537,16 @@ class Updater(AsyncContextManager["Updater"]):
                 header isn't set or it is set to a wrong token.
 
                 .. versionadded:: 20.0
+            unix (:class:`pathlib.Path` | :obj:`str`, optional): Path to the unix socket file. Path
+                does not need to exist, in which case the file will be created.
+
+                Caution:
+                    This parameter is a replacement for the default TCP bind. Therefore, it is
+                    mutually exclusive with :paramref:`listen` and :paramref:`port`. When using
+                    this param, you must also run a reverse proxy to the unix socket and set the
+                    appropriate :paramref:`webhook_url`.
+
+                .. versionadded:: 20.8
         Returns:
             :class:`queue.Queue`: The update queue that can be filled from the main thread.
 
@@ -499,6 +558,21 @@ class Updater(AsyncContextManager["Updater"]):
                 "To use `start_webhook`, PTB must be installed via `pip install "
                 '"python-telegram-bot[webhooks]"`.'
             )
+        # unix has special requirements what must and mustn't be set when using it
+        if unix:
+            error_msg = (
+                "You can not pass unix and {0}, only use one. Unix if you want to "
+                "initialize a unix socket, or {0} for a standard TCP server."
+            )
+            if not isinstance(listen, DefaultValue):
+                raise RuntimeError(error_msg.format("listen"))
+            if not isinstance(port, DefaultValue):
+                raise RuntimeError(error_msg.format("port"))
+            if not webhook_url:
+                raise RuntimeError(
+                    "Since you set unix, you also need to set the URL to the webhook "
+                    "of the proxy you run in front of the unix socket."
+                )
 
         async with self.__lock:
             if self.running:
@@ -513,8 +587,8 @@ class Updater(AsyncContextManager["Updater"]):
                 webhook_ready = asyncio.Event()
 
                 await self._start_webhook(
-                    listen=listen,
-                    port=port,
+                    listen=DefaultValue.get_value(listen),
+                    port=DefaultValue.get_value(port),
                     url_path=url_path,
                     cert=cert,
                     key=key,
@@ -526,6 +600,7 @@ class Updater(AsyncContextManager["Updater"]):
                     ip_address=ip_address,
                     max_connections=max_connections,
                     secret_token=secret_token,
+                    unix=unix,
                 )
 
                 _LOGGER.debug("Waiting for webhook server to start")
@@ -553,6 +628,7 @@ class Updater(AsyncContextManager["Updater"]):
         ip_address: Optional[str] = None,
         max_connections: int = 40,
         secret_token: Optional[str] = None,
+        unix: Optional[Union[str, Path]] = None,
     ) -> None:
         _LOGGER.debug("Updater thread started (webhook)")
 
@@ -577,14 +653,13 @@ class Updater(AsyncContextManager["Updater"]):
                 raise TelegramError("Invalid SSL Certificate") from exc
         else:
             ssl_ctx = None
-
         # Create and start server
-        self._httpd = WebhookServer(listen, port, app, ssl_ctx)
+        self._httpd = WebhookServer(listen, port, app, ssl_ctx, unix)
 
         if not webhook_url:
             webhook_url = self._gen_webhook_url(
                 protocol="https" if ssl_ctx else "http",
-                listen=listen,
+                listen=DefaultValue.get_value(listen),
                 port=port,
                 url_path=url_path,
             )
