@@ -81,7 +81,7 @@ class TrackingDict(UserDict, Generic[_KT, _VT]):
         :attr:`DELETED`.
         """
         keys = self.pop_accessed_keys()
-        return [(key, self[key] if key in self else self.DELETED) for key in keys]
+        return [(key, self.get(key, self.DELETED)) for key in keys]
 
     def mark_as_accessed(self, key: _KT) -> None:
         """Use this method have the key returned again in the next call to
@@ -99,7 +99,9 @@ class TrackingDict(UserDict, Generic[_KT, _VT]):
     # Mypy seems a bit inconsistent about what it wants as types for `default` and return value
     # so we just ignore a bit
     def pop(  # type: ignore[override]
-        self, key: _KT, default: _VT = DEFAULT_NONE  # type: ignore[assignment]
+        self,
+        key: _KT,
+        default: _VT = DEFAULT_NONE,  # type: ignore[assignment]
     ) -> _VT:
         if key in self:
             self.__track_write(key)
