@@ -20,15 +20,23 @@
 import asyncio
 import json
 from http import HTTPStatus
+from pathlib import Path
 from ssl import SSLContext
 from types import TracebackType
-from typing import TYPE_CHECKING, Optional, Type
+from typing import TYPE_CHECKING, Optional, Type, Union
 
 # Instead of checking for ImportError here, we do that in `updater.py`, where we import from
 # this module. Doing it here would be tricky, as the classes below subclass tornado classes
 import tornado.web
 from tornado.httpserver import HTTPServer
 
+try:
+    from tornado.netutil import bind_unix_socket
+
+    UNIX_AVAILABLE = True
+except ImportError:
+    UNIX_AVAILABLE = False
+
 from telegram import Update
 from telegram._utils.logging import get_logger
 from telegram.ext._extbot import ExtBot
@@ -45,26 +53,39 @@ class WebhookServer:
 
     __slots__ = (
         "_http_server",
-        "listen",
-        "port",
-        "is_running",
         "_server_lock",
         "_shutdown_lock",
+        "is_running",
+        "listen",
+        "port",
+        "unix",
     )
 
     def __init__(
-        self, listen: str, port: int, webhook_app: "WebhookAppClass", ssl_ctx: Optional[SSLContext]
+        self,
+        listen: str,
+        port: int,
+        webhook_app: "WebhookAppClass",
+        ssl_ctx: Optional[SSLContext],
+        unix: Optional[Union[str, Path]] = None,
     ):
+        if unix and not UNIX_AVAILABLE:
+            raise RuntimeError("This OS does not support binding unix sockets.")
         self._http_server = HTTPServer(webhook_app, ssl_options=ssl_ctx)
         self.listen = listen
         self.port = port
         self.is_running = False
+        self.unix = unix
         self._server_lock = asyncio.Lock()
         self._shutdown_lock = asyncio.Lock()
 
-    async def serve_forever(self, ready: asyncio.Event = None) -> None:
+    async def serve_forever(self, ready: Optional[asyncio.Event] = None) -> None:
         async with self._server_lock:
-            self._http_server.listen(self.port, address=self.listen)
+            if self.unix:
+                socket = bind_unix_socket(str(self.unix))
+                self._http_server.add_socket(socket)
+            else:
+                self._http_server.listen(self.port, address=self.listen)
 
             self.is_running = True
             if ready is not None:
@@ -87,7 +108,11 @@ class WebhookAppClass(tornado.web.Application):
     """Application used in the Webserver"""
 
     def __init__(
-        self, webhook_path: str, bot: "Bot", update_queue: asyncio.Queue, secret_token: str = None
+        self,
+        webhook_path: str,
+        bot: "Bot",
+        update_queue: asyncio.Queue,
+        secret_token: Optional[str] = None,
     ):
         self.shared_objects = {
             "bot": bot,
@@ -105,7 +130,7 @@ class WebhookAppClass(tornado.web.Application):
 class TelegramHandler(tornado.web.RequestHandler):
     """BaseHandler that processes incoming requests from Telegram"""
 
-    __slots__ = ("bot", "update_queue", "secret_token")
+    __slots__ = ("bot", "secret_token", "update_queue")
 
     SUPPORTED_METHODS = ("POST",)  # type: ignore[assignment]
 
@@ -113,8 +138,8 @@ class TelegramHandler(tornado.web.RequestHandler):
         """Initialize for each request - that's the interface provided by tornado"""
         # pylint: disable=attribute-defined-outside-init
         self.bot = bot
-        self.update_queue = update_queue  # skipcq: PYL-W0201
-        self.secret_token = secret_token  # skipcq: PYL-W0201
+        self.update_queue = update_queue
+        self.secret_token = secret_token
         if secret_token:
             _LOGGER.debug(
                 "The webhook server has a secret token, expecting it in incoming requests now"
@@ -142,6 +167,9 @@ class TelegramHandler(tornado.web.RequestHandler):
                 "Received data was *not* processed!",
                 exc_info=exc,
             )
+            raise tornado.web.HTTPError(
+                HTTPStatus.BAD_REQUEST, reason="Update could not be processed"
+            ) from exc
 
         if update:
             _LOGGER.debug(
