@@ -41,11 +41,36 @@ __all__ = (
     "ANIMATION",
     "ATTACHMENT",
     "AUDIO",
-    "BaseFilter",
     "CAPTION",
     "CHAT",
     "COMMAND",
     "CONTACT",
+    "FORWARDED",
+    "GAME",
+    "GIVEAWAY",
+    "GIVEAWAY_WINNERS",
+    "HAS_MEDIA_SPOILER",
+    "HAS_PROTECTED_CONTENT",
+    "INVOICE",
+    "IS_AUTOMATIC_FORWARD",
+    "IS_TOPIC_MESSAGE",
+    "LOCATION",
+    "PASSPORT_DATA",
+    "PHOTO",
+    "POLL",
+    "PREMIUM_USER",
+    "REPLY",
+    "STORY",
+    "SUCCESSFUL_PAYMENT",
+    "TEXT",
+    "USER",
+    "USER_ATTACHMENT",
+    "VENUE",
+    "VIA_BOT",
+    "VIDEO",
+    "VIDEO_NOTE",
+    "VOICE",
+    "BaseFilter",
     "Caption",
     "CaptionEntity",
     "CaptionRegex",
@@ -55,41 +80,19 @@ __all__ = (
     "Dice",
     "Document",
     "Entity",
-    "FORWARDED",
     "ForwardedFrom",
-    "GAME",
-    "HAS_MEDIA_SPOILER",
-    "HAS_PROTECTED_CONTENT",
-    "INVOICE",
-    "IS_AUTOMATIC_FORWARD",
-    "IS_TOPIC_MESSAGE",
-    "LOCATION",
     "Language",
-    "MessageFilter",
     "Mention",
-    "PASSPORT_DATA",
-    "PHOTO",
-    "POLL",
-    "REPLY",
+    "MessageFilter",
     "Regex",
-    "Sticker",
-    "STORY",
-    "SUCCESSFUL_PAYMENT",
     "SenderChat",
     "StatusUpdate",
-    "TEXT",
+    "Sticker",
+    "SuccessfulPayment",
     "Text",
-    "USER",
-    "USER_ATTACHMENT",
-    "PREMIUM_USER",
     "UpdateFilter",
     "UpdateType",
     "User",
-    "VENUE",
-    "VIA_BOT",
-    "VIDEO",
-    "VIDEO_NOTE",
-    "VOICE",
     "ViaBot",
 )
 import mimetypes
@@ -113,10 +116,18 @@ from typing import (
 )
 
 from telegram import Chat as TGChat
-from telegram import Message, MessageEntity, Update
+from telegram import (
+    Message,
+    MessageEntity,
+    MessageOriginChannel,
+    MessageOriginChat,
+    MessageOriginUser,
+    Update,
+)
 from telegram import User as TGUser
 from telegram._utils.types import SCT
 from telegram.constants import DiceEmoji as DiceEmojiEnum
+from telegram.ext._utils._update_parsing import parse_chat_id, parse_username
 from telegram.ext._utils.types import FilterDataDict
 
 
@@ -177,25 +188,64 @@ class BaseFilter:
             (depends on the handler).
     """
 
-    __slots__ = ("_name", "_data_filter")
+    __slots__ = ("_data_filter", "_name")
 
     def __init__(self, name: Optional[str] = None, data_filter: bool = False):
         self._name = self.__class__.__name__ if name is None else name
         self._data_filter = data_filter
 
     def __and__(self, other: "BaseFilter") -> "BaseFilter":
+        """Defines `AND` bitwise operator for :class:`BaseFilter` object.
+        The combined filter accepts an update only if it is accepted by both filters.
+        For example, ``filters.PHOTO & filters.CAPTION`` will only accept messages that contain
+        both a photo and a caption.
+
+        Returns:
+           :obj:`BaseFilter`
+        """
         return _MergedFilter(self, and_filter=other)
 
     def __or__(self, other: "BaseFilter") -> "BaseFilter":
+        """Defines `OR` bitwise operator for :class:`BaseFilter` object.
+        The combined filter accepts an update only if it is accepted by any of the filters.
+        For example, ``filters.PHOTO | filters.CAPTION`` will only accept messages that contain
+        photo or caption or both.
+
+        Returns:
+           :obj:`BaseFilter`
+        """
         return _MergedFilter(self, or_filter=other)
 
     def __xor__(self, other: "BaseFilter") -> "BaseFilter":
+        """Defines `XOR` bitwise operator for :class:`BaseFilter` object.
+        The combined filter accepts an update only if it is accepted by any of the filters and
+        not both of them. For example, ``filters.PHOTO ^ filters.CAPTION`` will only accept
+        messages that contain photo or caption, not both of them.
+
+        Returns:
+           :obj:`BaseFilter`
+        """
         return _XORFilter(self, other)
 
     def __invert__(self) -> "BaseFilter":
+        """Defines `NOT` bitwise operator for :class:`BaseFilter` object.
+        The combined filter accepts an update only if it is accepted by any of the filters.
+        For example, ``~ filters.PHOTO`` will only accept messages that do not contain photo.
+
+        Returns:
+           :obj:`BaseFilter`
+        """
         return _InvertedFilter(self)
 
     def __repr__(self) -> str:
+        """Gives name for this filter.
+
+        .. seealso::
+               :meth:`name`
+
+        Returns:
+            :obj:`str`:
+        """
         return self.name
 
     @property
@@ -216,9 +266,7 @@ class BaseFilter:
     def name(self, name: str) -> None:
         self._name = name
 
-    def check_update(  # skipcq: PYL-R0201
-        self, update: Update
-    ) -> Optional[Union[bool, FilterDataDict]]:
+    def check_update(self, update: Update) -> Optional[Union[bool, FilterDataDict]]:
         """Checks if the specified update should be handled by this filter.
 
         Args:
@@ -357,7 +405,7 @@ class _MergedFilter(UpdateFilter):
 
     """
 
-    __slots__ = ("base_filter", "and_filter", "or_filter")
+    __slots__ = ("and_filter", "base_filter", "or_filter")
 
     def __init__(
         self,
@@ -448,7 +496,7 @@ class _XORFilter(UpdateFilter):
 
     """
 
-    __slots__ = ("base_filter", "xor_filter", "merged_filter")
+    __slots__ = ("base_filter", "merged_filter", "xor_filter")
 
     def __init__(self, base_filter: BaseFilter, xor_filter: BaseFilter):
         super().__init__()
@@ -609,10 +657,10 @@ class CaptionRegex(MessageFilter):
 class _ChatUserBaseFilter(MessageFilter, ABC):
     __slots__ = (
         "_chat_id_name",
-        "_username_name",
-        "allow_empty",
         "_chat_ids",
+        "_username_name",
         "_usernames",
+        "allow_empty",
     )
 
     def __init__(
@@ -633,24 +681,7 @@ class _ChatUserBaseFilter(MessageFilter, ABC):
         self._set_usernames(username)
 
     @abstractmethod
-    def _get_chat_or_user(self, message: Message) -> Union[TGChat, TGUser, None]:
-        ...
-
-    @staticmethod
-    def _parse_chat_id(chat_id: Optional[SCT[int]]) -> Set[int]:
-        if chat_id is None:
-            return set()
-        if isinstance(chat_id, int):
-            return {chat_id}
-        return set(chat_id)
-
-    @staticmethod
-    def _parse_username(username: Optional[SCT[str]]) -> Set[str]:
-        if username is None:
-            return set()
-        if isinstance(username, str):
-            return {username[1:] if username.startswith("@") else username}
-        return {chat[1:] if chat.startswith("@") else chat for chat in username}
+    def _get_chat_or_user(self, message: Message) -> Union[TGChat, TGUser, None]: ...
 
     def _set_chat_ids(self, chat_id: Optional[SCT[int]]) -> None:
         if chat_id and self._usernames:
@@ -658,7 +689,7 @@ class _ChatUserBaseFilter(MessageFilter, ABC):
                 f"Can't set {self._chat_id_name} in conjunction with (already set) "
                 f"{self._username_name}s."
             )
-        self._chat_ids = self._parse_chat_id(chat_id)
+        self._chat_ids = set(parse_chat_id(chat_id))
 
     def _set_usernames(self, username: Optional[SCT[str]]) -> None:
         if username and self._chat_ids:
@@ -666,7 +697,7 @@ class _ChatUserBaseFilter(MessageFilter, ABC):
                 f"Can't set {self._username_name} in conjunction with (already set) "
                 f"{self._chat_id_name}s."
             )
-        self._usernames = self._parse_username(username)
+        self._usernames = set(parse_username(username))
 
     @property
     def chat_ids(self) -> FrozenSet[int]:
@@ -710,7 +741,7 @@ class _ChatUserBaseFilter(MessageFilter, ABC):
                 f"{self._chat_id_name}s."
             )
 
-        parsed_username = self._parse_username(username)
+        parsed_username = set(parse_username(username))
         self._usernames |= parsed_username
 
     def _add_chat_ids(self, chat_id: SCT[int]) -> None:
@@ -720,7 +751,7 @@ class _ChatUserBaseFilter(MessageFilter, ABC):
                 f"{self._username_name}s."
             )
 
-        parsed_chat_id = self._parse_chat_id(chat_id)
+        parsed_chat_id = set(parse_chat_id(chat_id))
 
         self._chat_ids |= parsed_chat_id
 
@@ -738,7 +769,7 @@ class _ChatUserBaseFilter(MessageFilter, ABC):
                 f"{self._chat_id_name}s."
             )
 
-        parsed_username = self._parse_username(username)
+        parsed_username = set(parse_username(username))
         self._usernames -= parsed_username
 
     def _remove_chat_ids(self, chat_id: SCT[int]) -> None:
@@ -747,7 +778,7 @@ class _ChatUserBaseFilter(MessageFilter, ABC):
                 f"Can't set {self._chat_id_name} in conjunction with (already set) "
                 f"{self._username_name}s."
             )
-        parsed_chat_id = self._parse_chat_id(chat_id)
+        parsed_chat_id = set(parse_chat_id(chat_id))
         self._chat_ids -= parsed_chat_id
 
     def filter(self, message: Message) -> bool:
@@ -837,7 +868,11 @@ class _Chat(MessageFilter):
 
 
 CHAT = _Chat(name="filters.CHAT")
-"""This filter filters *any* message that has a :attr:`telegram.Message.chat`."""
+"""This filter filters *any* message that has a :attr:`telegram.Message.chat`.
+
+.. deprecated:: 20.8
+   This filter has no effect since :attr:`telegram.Message.chat` is always present.
+"""
 
 
 class ChatType:  # A convenience namespace for Chat types.
@@ -1078,7 +1113,7 @@ class Dice(_Dice):
         def __init__(self, values: SCT[int]):
             super().__init__(values, emoji=DiceEmojiEnum.DICE)
 
-    DICE = _Dice(emoji=DiceEmojiEnum.DICE)  # skipcq: PTC-W0052
+    DICE = _Dice(emoji=DiceEmojiEnum.DICE)
     """Dice messages with the emoji 🎲. Matches any dice value."""
 
     class Football(_Dice):
@@ -1251,7 +1286,7 @@ class Document:
         __slots__ = ("mimetype",)
 
         def __init__(self, mimetype: str):
-            self.mimetype: str = mimetype  # skipcq: PTC-W0052
+            self.mimetype: str = mimetype
             super().__init__(name=f"filters.Document.MimeType('{self.mimetype}')")
 
         def filter(self, message: Message) -> bool:
@@ -1321,28 +1356,40 @@ class _Forwarded(MessageFilter):
     __slots__ = ()
 
     def filter(self, message: Message) -> bool:
-        return bool(message.forward_date)
+        return bool(message.forward_origin)
 
 
 FORWARDED = _Forwarded(name="filters.FORWARDED")
-"""Messages that contain :attr:`telegram.Message.forward_date`."""
+"""Messages that contain :attr:`telegram.Message.forward_origin`.
+
+.. versionchanged:: 20.8
+   Now based on :attr:`telegram.Message.forward_origin` instead of
+   :attr:`telegram.Message.forward_date`.
+"""
 
 
 class ForwardedFrom(_ChatUserBaseFilter):
     """Filters messages to allow only those which are forwarded from the specified chat ID(s)
-    or username(s) based on :attr:`telegram.Message.forward_from` and
-    :attr:`telegram.Message.forward_from_chat`.
+    or username(s) based on :attr:`telegram.Message.forward_origin` and in particular
+
+    * :attr:`telegram.MessageOriginUser.sender_user`
+    * :attr:`telegram.MessageOriginChat.sender_chat`
+    * :attr:`telegram.MessageOriginChannel.chat`
 
     .. versionadded:: 13.5
 
+    .. versionchanged:: 20.8
+       Was previously based on :attr:`telegram.Message.forward_from` and
+         :attr:`telegram.Message.forward_from_chat`.
+
     Examples:
         ``MessageHandler(filters.ForwardedFrom(chat_id=1234), callback_method)``
 
     Note:
         When a user has disallowed adding a link to their account while forwarding their
-        messages, this filter will *not* work since both
-        :attr:`telegram.Message.forward_from` and
-        :attr:`telegram.Message.forward_from_chat` are :obj:`None`. However, this behaviour
+        messages, this filter will *not* work since
+        :attr:`telegram.Message.forward_origin` will be of type
+        :class:`telegram.MessageOriginHiddenUser`. However, this behaviour
         is undocumented and might be changed by Telegram.
 
     Warning:
@@ -1373,7 +1420,17 @@ class ForwardedFrom(_ChatUserBaseFilter):
     __slots__ = ()
 
     def _get_chat_or_user(self, message: Message) -> Union[TGUser, TGChat, None]:
-        return message.forward_from or message.forward_from_chat
+        if (forward_origin := message.forward_origin) is None:
+            return None
+
+        if isinstance(forward_origin, MessageOriginUser):
+            return forward_origin.sender_user
+        if isinstance(forward_origin, MessageOriginChat):
+            return forward_origin.sender_chat
+        if isinstance(forward_origin, MessageOriginChannel):
+            return forward_origin.chat
+
+        return None
 
     def add_chat_ids(self, chat_id: SCT[int]) -> None:
         """
@@ -1407,6 +1464,28 @@ GAME = _Game(name="filters.GAME")
 """Messages that contain :attr:`telegram.Message.game`."""
 
 
+class _Giveaway(MessageFilter):
+    __slots__ = ()
+
+    def filter(self, message: Message) -> bool:
+        return bool(message.giveaway)
+
+
+GIVEAWAY = _Giveaway(name="filters.GIVEAWAY")
+"""Messages that contain :attr:`telegram.Message.giveaway`."""
+
+
+class _GiveawayWinners(MessageFilter):
+    __slots__ = ()
+
+    def filter(self, message: Message) -> bool:
+        return bool(message.giveaway_winners)
+
+
+GIVEAWAY_WINNERS = _GiveawayWinners(name="filters.GIVEAWAY_WINNERS")
+"""Messages that contain :attr:`telegram.Message.giveaway_winners`."""
+
+
 class _HasMediaSpoiler(MessageFilter):
     __slots__ = ()
 
@@ -1805,31 +1884,35 @@ class StatusUpdate:
 
         def filter(self, update: Update) -> bool:
             return bool(
-                StatusUpdate.NEW_CHAT_MEMBERS.check_update(update)
-                or StatusUpdate.LEFT_CHAT_MEMBER.check_update(update)
-                or StatusUpdate.NEW_CHAT_TITLE.check_update(update)
-                or StatusUpdate.NEW_CHAT_PHOTO.check_update(update)
-                or StatusUpdate.DELETE_CHAT_PHOTO.check_update(update)
-                or StatusUpdate.CHAT_CREATED.check_update(update)
-                or StatusUpdate.MESSAGE_AUTO_DELETE_TIMER_CHANGED.check_update(update)
-                or StatusUpdate.MIGRATE.check_update(update)
-                or StatusUpdate.PINNED_MESSAGE.check_update(update)
+                # keep this alphabetically sorted for easier maintenance
+                StatusUpdate.CHAT_CREATED.check_update(update)
+                or StatusUpdate.CHAT_SHARED.check_update(update)
                 or StatusUpdate.CONNECTED_WEBSITE.check_update(update)
-                or StatusUpdate.PROXIMITY_ALERT_TRIGGERED.check_update(update)
-                or StatusUpdate.VIDEO_CHAT_SCHEDULED.check_update(update)
-                or StatusUpdate.VIDEO_CHAT_STARTED.check_update(update)
-                or StatusUpdate.VIDEO_CHAT_ENDED.check_update(update)
-                or StatusUpdate.VIDEO_CHAT_PARTICIPANTS_INVITED.check_update(update)
-                or StatusUpdate.WEB_APP_DATA.check_update(update)
-                or StatusUpdate.FORUM_TOPIC_CREATED.check_update(update)
+                or StatusUpdate.DELETE_CHAT_PHOTO.check_update(update)
                 or StatusUpdate.FORUM_TOPIC_CLOSED.check_update(update)
-                or StatusUpdate.FORUM_TOPIC_REOPENED.check_update(update)
+                or StatusUpdate.FORUM_TOPIC_CREATED.check_update(update)
                 or StatusUpdate.FORUM_TOPIC_EDITED.check_update(update)
+                or StatusUpdate.FORUM_TOPIC_REOPENED.check_update(update)
                 or StatusUpdate.GENERAL_FORUM_TOPIC_HIDDEN.check_update(update)
                 or StatusUpdate.GENERAL_FORUM_TOPIC_UNHIDDEN.check_update(update)
-                or StatusUpdate.WRITE_ACCESS_ALLOWED.check_update(update)
+                or StatusUpdate.GIVEAWAY_COMPLETED.check_update(update)
+                or StatusUpdate.GIVEAWAY_CREATED.check_update(update)
+                or StatusUpdate.LEFT_CHAT_MEMBER.check_update(update)
+                or StatusUpdate.MESSAGE_AUTO_DELETE_TIMER_CHANGED.check_update(update)
+                or StatusUpdate.MIGRATE.check_update(update)
+                or StatusUpdate.NEW_CHAT_MEMBERS.check_update(update)
+                or StatusUpdate.NEW_CHAT_PHOTO.check_update(update)
+                or StatusUpdate.NEW_CHAT_TITLE.check_update(update)
+                or StatusUpdate.PINNED_MESSAGE.check_update(update)
+                or StatusUpdate.PROXIMITY_ALERT_TRIGGERED.check_update(update)
+                or StatusUpdate.USERS_SHARED.check_update(update)
                 or StatusUpdate.USER_SHARED.check_update(update)
-                or StatusUpdate.CHAT_SHARED.check_update(update)
+                or StatusUpdate.VIDEO_CHAT_ENDED.check_update(update)
+                or StatusUpdate.VIDEO_CHAT_PARTICIPANTS_INVITED.check_update(update)
+                or StatusUpdate.VIDEO_CHAT_SCHEDULED.check_update(update)
+                or StatusUpdate.VIDEO_CHAT_STARTED.check_update(update)
+                or StatusUpdate.WEB_APP_DATA.check_update(update)
+                or StatusUpdate.WRITE_ACCESS_ALLOWED.check_update(update)
             )
 
     ALL = _All(name="filters.StatusUpdate.ALL")
@@ -1956,6 +2039,29 @@ class StatusUpdate:
     .. versionadded:: 20.0
     """
 
+    class _GiveawayCreated(MessageFilter):
+        __slots__ = ()
+
+        def filter(self, message: Message) -> bool:
+            return bool(message.giveaway_created)
+
+    GIVEAWAY_CREATED = _GiveawayCreated(name="filters.StatusUpdate.GIVEAWAY_CREATED")
+    """Messages that contain :attr:`telegram.Message.giveaway_created`.
+
+    .. versionadded:: 20.8
+    """
+
+    class _GiveawayCompleted(MessageFilter):
+        __slots__ = ()
+
+        def filter(self, message: Message) -> bool:
+            return bool(message.giveaway_completed)
+
+    GIVEAWAY_COMPLETED = _GiveawayCompleted(name="filters.StatusUpdate.GIVEAWAY_COMPLETED")
+    """Messages that contain :attr:`telegram.Message.giveaway_completed`.
+    .. versionadded:: 20.8
+    """
+
     class _LeftChatMember(MessageFilter):
         __slots__ = ()
 
@@ -2045,7 +2151,25 @@ class StatusUpdate:
     USER_SHARED = _UserShared(name="filters.StatusUpdate.USER_SHARED")
     """Messages that contain :attr:`telegram.Message.user_shared`.
 
+    Warning:
+        This will only catch the legacy :attr:`telegram.Message.user_shared` attribute, not the
+        new :attr:`telegram.Message.users_shared` attribute!
+
     .. versionadded:: 20.1
+    .. deprecated:: 20.8
+       Use :attr:`USERS_SHARED` instead.
+    """
+
+    class _UsersShared(MessageFilter):
+        __slots__ = ()
+
+        def filter(self, message: Message) -> bool:
+            return bool(message.users_shared)
+
+    USERS_SHARED = _UsersShared(name="filters.StatusUpdate.USERS_SHARED")
+    """Messages that contain :attr:`telegram.Message.users_shared`.
+
+    .. versionadded:: 20.8
     """
 
     class _VideoChatEnded(MessageFilter):
@@ -2226,14 +2350,47 @@ STORY = _Story(name="filters.STORY")
 """
 
 
-class _SuccessfulPayment(MessageFilter):
-    __slots__ = ()
+class SuccessfulPayment(MessageFilter):
+    """Successful Payment Messages. If a list of invoice payloads is passed, it filters
+    messages to only allow those whose `invoice_payload` is appearing in the given list.
+
+    Examples:
+        `MessageHandler(filters.SuccessfulPayment(['Custom-Payload']), callback_method)`
+
+    .. seealso::
+        :attr:`telegram.ext.filters.SUCCESSFUL_PAYMENT`
+
+    Args:
+        invoice_payloads (List[:obj:`str`] | Tuple[:obj:`str`], optional): Which
+            invoice payloads to allow. Only exact matches are allowed. If not
+            specified, will allow any invoice payload.
+
+    .. versionadded:: 20.8
+    """
+
+    __slots__ = ("invoice_payloads",)
+
+    def __init__(self, invoice_payloads: Optional[Union[List[str], Tuple[str, ...]]] = None):
+        self.invoice_payloads: Optional[Sequence[str]] = invoice_payloads
+        super().__init__(
+            name=(
+                f"filters.SuccessfulPayment({invoice_payloads})"
+                if invoice_payloads
+                else "filters.SUCCESSFUL_PAYMENT"
+            )
+        )
 
     def filter(self, message: Message) -> bool:
-        return bool(message.successful_payment)
+        if self.invoice_payloads is None:
+            return bool(message.successful_payment)
+        return (
+            payment.invoice_payload in self.invoice_payloads
+            if (payment := message.successful_payment)
+            else False
+        )
 
 
-SUCCESSFUL_PAYMENT = _SuccessfulPayment(name="filters.SUCCESSFUL_PAYMENT")
+SUCCESSFUL_PAYMENT = SuccessfulPayment()
 """Messages that contain :attr:`telegram.Message.successful_payment`."""
 
 
