@@ -17,23 +17,25 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains methods to make POST and GET requests using the httpx library."""
-import logging
-from typing import Optional, Tuple
+from typing import Collection, Optional, Tuple, Union
 
 import httpx
 
 from telegram._utils.defaultvalue import DefaultValue
-from telegram._utils.types import ODVInput
+from telegram._utils.logging import get_logger
+from telegram._utils.types import HTTPVersion, ODVInput, SocketOpt
+from telegram._utils.warnings import warn
 from telegram.error import NetworkError, TimedOut
 from telegram.request._baserequest import BaseRequest
 from telegram.request._requestdata import RequestData
+from telegram.warnings import PTBDeprecationWarning
 
 # Note to future devs:
 # Proxies are currently only tested manually. The httpx development docs have a nice guide on that:
 # https://www.python-httpx.org/contributing/#development-proxy-setup (also saved on archive.org)
 # That also works with socks5. Just pass `--mode socks5` to mitmproxy
 
-_logger = logging.getLogger(__name__)
+_LOGGER = get_logger(__name__, "HTTPXRequest")
 
 
 class HTTPXRequest(BaseRequest):
@@ -49,17 +51,10 @@ class HTTPXRequest(BaseRequest):
             Note:
                 Independent of the value, one additional connection will be reserved for
                 :meth:`telegram.Bot.get_updates`.
-        proxy_url (:obj:`str`, optional): The URL to the proxy server. For example
-            ``'http://127.0.0.1:3128'`` or ``'socks5://127.0.0.1:3128'``. Defaults to :obj:`None`.
+        proxy_url (:obj:`str`, optional): Legacy name for :paramref:`proxy`, kept for backward
+            compatibility. Defaults to :obj:`None`.
 
-            Note:
-                * The proxy URL can also be set via the environment variables ``HTTPS_PROXY`` or
-                  ``ALL_PROXY``. See `the docs of httpx`_ for more info.
-                * For Socks5 support, additional dependencies are required. Make sure to install
-                  PTB via :command:`pip install python-telegram-bot[socks]` in this case.
-                * Socks5 proxies can not be set via environment variables.
-
-            .. _the docs of httpx: https://www.python-httpx.org/environment_variables/#proxies
+            .. deprecated:: 20.7
         read_timeout (:obj:`float` | :obj:`None`, optional): If passed, specifies the maximum
             amount of time (in seconds) to wait for a response from Telegram's server.
             This value is used unless a different value is passed to :meth:`do_request`.
@@ -82,13 +77,42 @@ class HTTPXRequest(BaseRequest):
                 With a finite pool timeout, you must expect :exc:`telegram.error.TimedOut`
                 exceptions to be thrown when more requests are made simultaneously than there are
                 connections in the connection pool!
-        http_version (:obj:`str`, optional): If ``"2"``, HTTP/2 will be used instead of HTTP/1.1.
-            Defaults to ``"1.1"``.
+        http_version (:obj:`str`, optional): If ``"2"`` or ``"2.0"``, HTTP/2 will be used instead
+            of HTTP/1.1. Defaults to ``"1.1"``.
 
             .. versionadded:: 20.1
             .. versionchanged:: 20.2
                 Reset the default version to 1.1.
 
+            .. versionchanged:: 20.5
+                Accept ``"2"`` as a valid value.
+        socket_options (Collection[:obj:`tuple`], optional): Socket options to be passed to the
+            underlying `library \
+            <https://www.encode.io/httpcore/async/#httpcore.AsyncConnectionPool.__init__>`_.
+
+            Note:
+                The values accepted by this parameter depend on the operating system.
+                This is a low-level parameter and should only be used if you are familiar with
+                these concepts.
+
+            .. versionadded:: 20.7
+        proxy (:obj:`str` | ``httpx.Proxy`` | ``httpx.URL``, optional): The URL to a proxy server,
+            a ``httpx.Proxy`` object or a ``httpx.URL`` object. For example
+            ``'http://127.0.0.1:3128'`` or ``'socks5://127.0.0.1:3128'``. Defaults to :obj:`None`.
+
+            Note:
+                * The proxy URL can also be set via the environment variables ``HTTPS_PROXY`` or
+                  ``ALL_PROXY``. See `the docs of httpx`_ for more info.
+                * HTTPS proxies can be configured by passing a ``httpx.Proxy`` object with
+                  a corresponding ``ssl_context``.
+                * For Socks5 support, additional dependencies are required. Make sure to install
+                  PTB via :command:`pip install "python-telegram-bot[socks]"` in this case.
+                * Socks5 proxies can not be set via environment variables.
+
+            .. _the docs of httpx: https://www.python-httpx.org/environment_variables/#proxies
+
+            .. versionadded:: 20.7
+
     """
 
     __slots__ = ("_client", "_client_kwargs", "_http_version")
@@ -96,13 +120,27 @@ class HTTPXRequest(BaseRequest):
     def __init__(
         self,
         connection_pool_size: int = 1,
-        proxy_url: str = None,
+        proxy_url: Optional[Union[str, httpx.Proxy, httpx.URL]] = None,
         read_timeout: Optional[float] = 5.0,
         write_timeout: Optional[float] = 5.0,
         connect_timeout: Optional[float] = 5.0,
         pool_timeout: Optional[float] = 1.0,
-        http_version: str = "1.1",
+        http_version: HTTPVersion = "1.1",
+        socket_options: Optional[Collection[SocketOpt]] = None,
+        proxy: Optional[Union[str, httpx.Proxy, httpx.URL]] = None,
     ):
+        if proxy_url is not None and proxy is not None:
+            raise ValueError("The parameters `proxy_url` and `proxy` are mutually exclusive.")
+
+        if proxy_url is not None:
+            proxy = proxy_url
+            warn(
+                "The parameter `proxy_url` is deprecated since version 20.7. Use `proxy` "
+                "instead.",
+                PTBDeprecationWarning,
+                stacklevel=2,
+            )
+
         self._http_version = http_version
         timeout = httpx.Timeout(
             connect=connect_timeout,
@@ -115,20 +153,25 @@ class HTTPXRequest(BaseRequest):
             max_keepalive_connections=connection_pool_size,
         )
 
-        if http_version not in ("1.1", "2"):
-            raise ValueError("`http_version` must be either '1.1' or '2'.")
+        if http_version not in ("1.1", "2", "2.0"):
+            raise ValueError("`http_version` must be either '1.1', '2.0' or '2'.")
 
         http1 = http_version == "1.1"
-
-        # See https://github.com/python-telegram-bot/python-telegram-bot/pull/3542
-        # for why we need to use `dict()` here.
-        self._client_kwargs = dict(  # pylint: disable=use-dict-literal
-            timeout=timeout,
-            proxies=proxy_url,
-            limits=limits,
-            http1=http1,
-            http2=not http1,
+        http_kwargs = {"http1": http1, "http2": not http1}
+        transport = (
+            httpx.AsyncHTTPTransport(
+                socket_options=socket_options,
+            )
+            if socket_options
+            else None
         )
+        self._client_kwargs = {
+            "timeout": timeout,
+            "proxy": proxy,
+            "limits": limits,
+            "transport": transport,
+            **http_kwargs,
+        }
 
         try:
             self._client = self._build_client()
@@ -139,11 +182,11 @@ class HTTPXRequest(BaseRequest):
             if "httpx[socks]" in str(exc):
                 raise RuntimeError(
                     "To use Socks5 proxies, PTB must be installed via `pip install "
-                    "python-telegram-bot[socks]`."
+                    '"python-telegram-bot[socks]"`.'
                 ) from exc
             raise RuntimeError(
                 "To use HTTP/2, PTB must be installed via `pip install "
-                "python-telegram-bot[http2]`."
+                '"python-telegram-bot[http2]"`.'
             ) from exc
 
     @property
@@ -155,6 +198,16 @@ class HTTPXRequest(BaseRequest):
         """
         return self._http_version
 
+    @property
+    def read_timeout(self) -> Optional[float]:
+        """See :attr:`BaseRequest.read_timeout`.
+
+        Returns:
+            :obj:`float` | :obj:`None`: The default read timeout in seconds as passed to
+                :paramref:`HTTPXRequest.read_timeout`.
+        """
+        return self._client.timeout.read
+
     def _build_client(self) -> httpx.AsyncClient:
         return httpx.AsyncClient(**self._client_kwargs)  # type: ignore[arg-type]
 
@@ -166,7 +219,7 @@ class HTTPXRequest(BaseRequest):
     async def shutdown(self) -> None:
         """See :meth:`BaseRequest.shutdown`."""
         if self._client.is_closed:
-            _logger.debug("This HTTPXRequest is already shut down. Returning.")
+            _LOGGER.debug("This HTTPXRequest is already shut down. Returning.")
             return
 
         await self._client.aclose()
@@ -175,7 +228,7 @@ class HTTPXRequest(BaseRequest):
         self,
         url: str,
         method: str,
-        request_data: RequestData = None,
+        request_data: Optional[RequestData] = None,
         read_timeout: ODVInput[float] = BaseRequest.DEFAULT_NONE,
         write_timeout: ODVInput[float] = BaseRequest.DEFAULT_NONE,
         connect_timeout: ODVInput[float] = BaseRequest.DEFAULT_NONE,
@@ -185,17 +238,25 @@ class HTTPXRequest(BaseRequest):
         if self._client.is_closed:
             raise RuntimeError("This HTTPXRequest is not initialized!")
 
+        files = request_data.multipart_data if request_data else None
+        data = request_data.json_parameters if request_data else None
+
         # If user did not specify timeouts (for e.g. in a bot method), use the default ones when we
         # created this instance.
         if isinstance(read_timeout, DefaultValue):
             read_timeout = self._client.timeout.read
-        if isinstance(write_timeout, DefaultValue):
-            write_timeout = self._client.timeout.write
         if isinstance(connect_timeout, DefaultValue):
             connect_timeout = self._client.timeout.connect
         if isinstance(pool_timeout, DefaultValue):
             pool_timeout = self._client.timeout.pool
 
+        if isinstance(write_timeout, DefaultValue):
+            # Making the networking backend decide on the proper timeout values instead of doing
+            # it via the default values of the Bot methods was introduced in version 20.7.
+            # We hard-code the value here for now until we add additional parameters to this
+            # class to control the media_write_timeout separately.
+            write_timeout = self._client.timeout.write if not files else 20
+
         timeout = httpx.Timeout(
             connect=connect_timeout,
             read=read_timeout,
@@ -203,15 +264,6 @@ class HTTPXRequest(BaseRequest):
             pool=pool_timeout,
         )
 
-        # TODO p0: On Linux, use setsockopt to properly set socket level keepalive.
-        #          (socket.IPPROTO_TCP, socket.TCP_KEEPIDLE, 120)
-        #          (socket.IPPROTO_TCP, socket.TCP_KEEPINTVL, 30)
-        #          (socket.IPPROTO_TCP, socket.TCP_KEEPCNT, 8)
-        # TODO p4: Support setsockopt on lesser platforms than Linux.
-
-        files = request_data.multipart_data if request_data else None
-        data = request_data.json_parameters if request_data else None
-
         try:
             res = await self._client.request(
                 method=method,
