@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -19,33 +19,34 @@
 
 import pytest
 
-from telegram import Location, ChatLocation, User
+from telegram import ChatLocation, Location, User
+from tests.auxil.slots import mro_slots
 
 
-@pytest.fixture(scope='class')
-def chat_location(bot):
-    return ChatLocation(TestChatLocation.location, TestChatLocation.address)
+@pytest.fixture(scope="module")
+def chat_location():
+    return ChatLocation(TestChatLocationBase.location, TestChatLocationBase.address)
 
 
-class TestChatLocation:
+class TestChatLocationBase:
     location = Location(123, 456)
-    address = 'The Shire'
+    address = "The Shire"
 
-    def test_slot_behaviour(self, chat_location, recwarn, mro_slots):
+
+class TestChatLocationWithoutRequest(TestChatLocationBase):
+    def test_slot_behaviour(self, chat_location):
         inst = chat_location
         for attr in inst.__slots__:
-            assert getattr(inst, attr, 'err') != 'err', f"got extra slot '{attr}'"
-        assert not inst.__dict__, f"got missing slot(s): {inst.__dict__}"
+            assert getattr(inst, attr, "err") != "err", f"got extra slot '{attr}'"
         assert len(mro_slots(inst)) == len(set(mro_slots(inst))), "duplicate slot"
-        inst.custom, inst.address = 'should give warning', self.address
-        assert len(recwarn) == 1 and 'custom' in str(recwarn[0].message), recwarn.list
 
     def test_de_json(self, bot):
         json_dict = {
-            'location': self.location.to_dict(),
-            'address': self.address,
+            "location": self.location.to_dict(),
+            "address": self.address,
         }
         chat_location = ChatLocation.de_json(json_dict, bot)
+        assert chat_location.api_kwargs == {}
 
         assert chat_location.location == self.location
         assert chat_location.address == self.address
@@ -54,15 +55,15 @@ class TestChatLocation:
         chat_location_dict = chat_location.to_dict()
 
         assert isinstance(chat_location_dict, dict)
-        assert chat_location_dict['location'] == chat_location.location.to_dict()
-        assert chat_location_dict['address'] == chat_location.address
+        assert chat_location_dict["location"] == chat_location.location.to_dict()
+        assert chat_location_dict["address"] == chat_location.address
 
     def test_equality(self, chat_location):
         a = chat_location
         b = ChatLocation(self.location, self.address)
-        c = ChatLocation(self.location, 'Mordor')
+        c = ChatLocation(self.location, "Mordor")
         d = ChatLocation(Location(456, 132), self.address)
-        e = User(456, '', False)
+        e = User(456, "", False)
 
         assert a == b
         assert hash(a) == hash(b)
