@@ -17,12 +17,18 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 import asyncio
+import inspect
 import json
+import re
 
-from telegram import constants
+import pytest
+
+from telegram import Message, constants
 from telegram._utils.enum import IntEnum, StringEnum
 from telegram.error import BadRequest
+from tests.auxil.build_messages import make_message
 from tests.auxil.files import data_file
+from tests.auxil.string_manipulation import to_snake_case
 
 
 class StrEnumTest(StringEnum):
@@ -47,7 +53,7 @@ class TestConstantsWithoutRequest:
                 not key.startswith("_")
                 # exclude imported stuff
                 and getattr(member, "__module__", "telegram.constants") == "telegram.constants"
-                and key != "sys"
+                and key not in ("sys", "datetime")
             )
         }
         actual = set(constants.__all__)
@@ -128,6 +134,96 @@ class TestConstantsWithoutRequest:
         assert vi[0] == vi.major
         assert vi[1] == vi.minor
 
+    @staticmethod
+    def is_type_attribute(name: str) -> bool:
+        # Return False if the attribute doesn't generate a message type, i.e. only message
+        # metadata. Manually excluding a lot of attributes here is a bit of work, but it makes
+        # sure that we don't miss any new message types in the future.
+        patters = {
+            "(text|caption)_(markdown|html)",
+            "caption_(entities|html|markdown)",
+            "(edit_)?date",
+            "forward_",
+            "has_",
+        }
+
+        if any(re.match(pattern, name) for pattern in patters):
+            return False
+        if name in {
+            "author_signature",
+            "api_kwargs",
+            "caption",
+            "chat",
+            "chat_id",
+            "effective_attachment",
+            "entities",
+            "from_user",
+            "id",
+            "is_automatic_forward",
+            "is_topic_message",
+            "link",
+            "link_preview_options",
+            "media_group_id",
+            "message_id",
+            "message_thread_id",
+            "migrate_from_chat_id",
+            "reply_markup",
+            "reply_to_message",
+            "sender_chat",
+            "is_accessible",
+            "quote",
+            "external_reply",
+            # attribute is deprecated, no need to add it to MessageType
+            "user_shared",
+            "via_bot",
+        }:
+            return False
+
+        return True
+
+    @pytest.mark.parametrize(
+        "attribute",
+        [
+            name
+            for name, _ in inspect.getmembers(
+                make_message("test"), lambda x: not inspect.isroutine(x)
+            )
+        ],
+    )
+    def test_message_type_completeness(self, attribute):
+        if attribute.startswith("_") or not self.is_type_attribute(attribute):
+            return
+
+        assert hasattr(constants.MessageType, attribute.upper()), (
+            f"Missing MessageType.{attribute}. Please also check if this should be present in "
+            f"MessageAttachmentType."
+        )
+
+    @pytest.mark.parametrize("member", constants.MessageType)
+    def test_message_type_completeness_reverse(self, member):
+        assert self.is_type_attribute(
+            member.value
+        ), f"Additional member {member} in MessageType that should not be a message type"
+
+    @pytest.mark.parametrize("member", constants.MessageAttachmentType)
+    def test_message_attachment_type_completeness(self, member):
+        try:
+            constants.MessageType(member)
+        except ValueError:
+            pytest.fail(f"Missing MessageType for {member}")
+
+    def test_message_attachment_type_completeness_reverse(self):
+        # Getting the type hints of a property is a bit tricky, so we instead parse the docstring
+        # for now
+        for match in re.finditer(r"`telegram.(\w+)`", Message.effective_attachment.__doc__):
+            name = to_snake_case(match.group(1))
+            if name == "photo_size":
+                name = "photo"
+            try:
+                constants.MessageAttachmentType(name)
+            except ValueError:
+                pytest.fail(f"Missing MessageAttachmentType for {match.group(1)}")
+
 
 class TestConstantsWithRequest:
     async def test_max_message_length(self, bot, chat_id):
