@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -19,40 +19,40 @@
 import pytest
 
 from telegram import LoginUrl
+from tests.auxil.slots import mro_slots
 
 
-@pytest.fixture(scope='class')
+@pytest.fixture(scope="module")
 def login_url():
     return LoginUrl(
-        url=TestLoginUrl.url,
-        forward_text=TestLoginUrl.forward_text,
-        bot_username=TestLoginUrl.bot_username,
-        request_write_access=TestLoginUrl.request_write_access,
+        url=TestLoginUrlBase.url,
+        forward_text=TestLoginUrlBase.forward_text,
+        bot_username=TestLoginUrlBase.bot_username,
+        request_write_access=TestLoginUrlBase.request_write_access,
     )
 
 
-class TestLoginUrl:
+class TestLoginUrlBase:
     url = "http://www.google.com"
     forward_text = "Send me forward!"
     bot_username = "botname"
     request_write_access = True
 
-    def test_slot_behaviour(self, login_url, recwarn, mro_slots):
+
+class TestLoginUrlWithoutRequest(TestLoginUrlBase):
+    def test_slot_behaviour(self, login_url):
         for attr in login_url.__slots__:
-            assert getattr(login_url, attr, 'err') != 'err', f"got extra slot '{attr}'"
-        assert not login_url.__dict__, f"got missing slot(s): {login_url.__dict__}"
+            assert getattr(login_url, attr, "err") != "err", f"got extra slot '{attr}'"
         assert len(mro_slots(login_url)) == len(set(mro_slots(login_url))), "duplicate slot"
-        login_url.custom, login_url.url = 'should give warning', self.url
-        assert len(recwarn) == 1 and 'custom' in str(recwarn[0].message), recwarn.list
 
     def test_to_dict(self, login_url):
         login_url_dict = login_url.to_dict()
 
         assert isinstance(login_url_dict, dict)
-        assert login_url_dict['url'] == self.url
-        assert login_url_dict['forward_text'] == self.forward_text
-        assert login_url_dict['bot_username'] == self.bot_username
-        assert login_url_dict['request_write_access'] == self.request_write_access
+        assert login_url_dict["url"] == self.url
+        assert login_url_dict["forward_text"] == self.forward_text
+        assert login_url_dict["bot_username"] == self.bot_username
+        assert login_url_dict["request_write_access"] == self.request_write_access
 
     def test_equality(self):
         a = LoginUrl(self.url, self.forward_text, self.bot_username, self.request_write_access)
