@@ -20,9 +20,10 @@ import pytest
 
 from telegram import MessageEntity, User
 from telegram.constants import MessageEntityType
+from tests.auxil.slots import mro_slots
 
 
-@pytest.fixture(scope="class", params=MessageEntity.ALL_TYPES)
+@pytest.fixture(scope="module", params=MessageEntity.ALL_TYPES)
 def message_entity(request):
     type_ = request.param
     url = None
@@ -37,13 +38,15 @@ def message_entity(request):
     return MessageEntity(type_, 1, 3, url=url, user=user, language=language)
 
 
-class TestMessageEntity:
+class TestMessageEntityBase:
     type_ = "url"
     offset = 1
     length = 2
     url = "url"
 
-    def test_slot_behaviour(self, message_entity, mro_slots):
+
+class TestMessageEntityWithoutRequest(TestMessageEntityBase):
+    def test_slot_behaviour(self, message_entity):
         inst = message_entity
         for attr in inst.__slots__:
             assert getattr(inst, attr, "err") != "err", f"got extra slot '{attr}'"
