@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -16,28 +16,28 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 import pytest
+
 from telegram import MessageId, User
+from tests.auxil.slots import mro_slots
 
 
-@pytest.fixture(scope="class")
+@pytest.fixture(scope="module")
 def message_id():
-    return MessageId(message_id=TestMessageId.m_id)
+    return MessageId(message_id=TestMessageIdWithoutRequest.m_id)
 
 
-class TestMessageId:
+class TestMessageIdWithoutRequest:
     m_id = 1234
 
-    def test_slot_behaviour(self, message_id, recwarn, mro_slots):
+    def test_slot_behaviour(self, message_id):
         for attr in message_id.__slots__:
-            assert getattr(message_id, attr, 'err') != 'err', f"got extra slot '{attr}'"
-        assert not message_id.__dict__, f"got missing slot(s): {message_id.__dict__}"
+            assert getattr(message_id, attr, "err") != "err", f"got extra slot '{attr}'"
         assert len(mro_slots(message_id)) == len(set(mro_slots(message_id))), "duplicate slot"
-        message_id.custom, message_id.message_id = 'should give warning', self.m_id
-        assert len(recwarn) == 1 and 'custom' in str(recwarn[0].message), recwarn.list
 
     def test_de_json(self):
-        json_dict = {'message_id': self.m_id}
+        json_dict = {"message_id": self.m_id}
         message_id = MessageId.de_json(json_dict, None)
+        assert message_id.api_kwargs == {}
 
         assert message_id.message_id == self.m_id
 
@@ -45,13 +45,13 @@ class TestMessageId:
         message_id_dict = message_id.to_dict()
 
         assert isinstance(message_id_dict, dict)
-        assert message_id_dict['message_id'] == message_id.message_id
+        assert message_id_dict["message_id"] == message_id.message_id
 
     def test_equality(self):
         a = MessageId(message_id=1)
         b = MessageId(message_id=1)
         c = MessageId(message_id=2)
-        d = User(id=1, first_name='name', is_bot=False)
+        d = User(id=1, first_name="name", is_bot=False)
 
         assert a == b
         assert hash(a) == hash(b)
