@@ -19,31 +19,26 @@
 import pytest
 
 from telegram import ReplyKeyboardRemove
+from tests.auxil.slots import mro_slots
 
 
-@pytest.fixture(scope="class")
+@pytest.fixture(scope="module")
 def reply_keyboard_remove():
-    return ReplyKeyboardRemove(selective=TestReplyKeyboardRemove.selective)
+    return ReplyKeyboardRemove(selective=TestReplyKeyboardRemoveBase.selective)
 
 
-class TestReplyKeyboardRemove:
+class TestReplyKeyboardRemoveBase:
     remove_keyboard = True
     selective = True
 
-    def test_slot_behaviour(self, reply_keyboard_remove, mro_slots):
+
+class TestReplyKeyboardRemoveWithoutRequest(TestReplyKeyboardRemoveBase):
+    def test_slot_behaviour(self, reply_keyboard_remove):
         inst = reply_keyboard_remove
         for attr in inst.__slots__:
             assert getattr(inst, attr, "err") != "err", f"got extra slot '{attr}'"
         assert len(mro_slots(inst)) == len(set(mro_slots(inst))), "duplicate slot"
 
-    @pytest.mark.flaky(3, 1)
-    async def test_send_message_with_reply_keyboard_remove(
-        self, bot, chat_id, reply_keyboard_remove
-    ):
-        message = await bot.send_message(chat_id, "Text", reply_markup=reply_keyboard_remove)
-
-        assert message.text == "Text"
-
     def test_expected_values(self, reply_keyboard_remove):
         assert reply_keyboard_remove.remove_keyboard == self.remove_keyboard
         assert reply_keyboard_remove.selective == self.selective
@@ -55,3 +50,11 @@ class TestReplyKeyboardRemove:
             reply_keyboard_remove_dict["remove_keyboard"] == reply_keyboard_remove.remove_keyboard
         )
         assert reply_keyboard_remove_dict["selective"] == reply_keyboard_remove.selective
+
+
+class TestReplyKeyboardRemoveWithRequest(TestReplyKeyboardRemoveBase):
+    async def test_send_message_with_reply_keyboard_remove(
+        self, bot, chat_id, reply_keyboard_remove
+    ):
+        message = await bot.send_message(chat_id, "Text", reply_markup=reply_keyboard_remove)
+        assert message.text == "Text"
