@@ -27,21 +27,22 @@ from telegram import (
     VideoChatScheduled,
     VideoChatStarted,
 )
-from telegram._utils.datetime import to_timestamp
+from telegram._utils.datetime import UTC, to_timestamp
+from tests.auxil.slots import mro_slots
 
 
-@pytest.fixture(scope="class")
+@pytest.fixture(scope="module")
 def user1():
     return User(first_name="Misses Test", id=123, is_bot=False)
 
 
-@pytest.fixture(scope="class")
+@pytest.fixture(scope="module")
 def user2():
     return User(first_name="Mister Test", id=124, is_bot=False)
 
 
-class TestVideoChatStarted:
-    def test_slot_behaviour(self, mro_slots):
+class TestVideoChatStartedWithoutRequest:
+    def test_slot_behaviour(self):
         action = VideoChatStarted()
         for attr in action.__slots__:
             assert getattr(action, attr, "err") != "err", f"got extra slot '{attr}'"
@@ -58,10 +59,10 @@ class TestVideoChatStarted:
         assert video_chat_dict == {}
 
 
-class TestVideoChatEnded:
+class TestVideoChatEndedWithoutRequest:
     duration = 100
 
-    def test_slot_behaviour(self, mro_slots):
+    def test_slot_behaviour(self):
         action = VideoChatEnded(8)
         for attr in action.__slots__:
             assert getattr(action, attr, "err") != "err", f"got extra slot '{attr}'"
@@ -97,8 +98,8 @@ class TestVideoChatEnded:
         assert hash(a) != hash(d)
 
 
-class TestVideoChatParticipantsInvited:
-    def test_slot_behaviour(self, mro_slots, user1):
+class TestVideoChatParticipantsInvitedWithoutRequest:
+    def test_slot_behaviour(self, user1):
         action = VideoChatParticipantsInvited([user1])
         for attr in action.__slots__:
             assert getattr(action, attr, "err") != "err", f"got extra slot '{attr}'"
@@ -115,7 +116,7 @@ class TestVideoChatParticipantsInvited:
         assert video_chat_participants.users[0].id == user1.id
         assert video_chat_participants.users[1].id == user2.id
 
-    @pytest.mark.parametrize("use_users", (True, False))
+    @pytest.mark.parametrize("use_users", [True, False])
     def test_to_dict(self, user1, user2, use_users):
         video_chat_participants = VideoChatParticipantsInvited([user1, user2] if use_users else ())
         video_chat_dict = video_chat_participants.to_dict()
@@ -148,10 +149,10 @@ class TestVideoChatParticipantsInvited:
         assert hash(a) != hash(e)
 
 
-class TestVideoChatScheduled:
+class TestVideoChatScheduledWithoutRequest:
     start_date = dtm.datetime.now(dtm.timezone.utc)
 
-    def test_slot_behaviour(self, mro_slots):
+    def test_slot_behaviour(self):
         inst = VideoChatScheduled(self.start_date)
         for attr in inst.__slots__:
             assert getattr(inst, attr, "err") != "err", f"got extra slot '{attr}'"
@@ -169,6 +170,23 @@ class TestVideoChatScheduled:
 
         assert abs(video_chat_scheduled.start_date - self.start_date) < dtm.timedelta(seconds=1)
 
+    def test_de_json_localization(self, tz_bot, bot, raw_bot):
+        json_dict = {"start_date": to_timestamp(self.start_date)}
+
+        videochat_raw = VideoChatScheduled.de_json(json_dict, raw_bot)
+        videochat_bot = VideoChatScheduled.de_json(json_dict, bot)
+        videochat_tz = VideoChatScheduled.de_json(json_dict, tz_bot)
+
+        # comparing utcoffsets because comparing timezones is unpredicatable
+        videochat_offset = videochat_tz.start_date.utcoffset()
+        tz_bot_offset = tz_bot.defaults.tzinfo.utcoffset(
+            videochat_tz.start_date.replace(tzinfo=None)
+        )
+
+        assert videochat_raw.start_date.tzinfo == UTC
+        assert videochat_bot.start_date.tzinfo == UTC
+        assert videochat_offset == tz_bot_offset
+
     def test_to_dict(self):
         video_chat_scheduled = VideoChatScheduled(self.start_date)
         video_chat_scheduled_dict = video_chat_scheduled.to_dict()
