@@ -17,10 +17,11 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 from telegram import WriteAccessAllowed
+from tests.auxil.slots import mro_slots
 
 
 class TestWriteAccessAllowed:
-    def test_slot_behaviour(self, mro_slots):
+    def test_slot_behaviour(self):
         action = WriteAccessAllowed()
         for attr in action.__slots__:
             assert getattr(action, attr, "err") != "err", f"got extra slot '{attr}'"
@@ -35,3 +36,22 @@ class TestWriteAccessAllowed:
         action = WriteAccessAllowed()
         action_dict = action.to_dict()
         assert action_dict == {}
+
+    def test_equality(self):
+        a = WriteAccessAllowed()
+        b = WriteAccessAllowed()
+        c = WriteAccessAllowed(web_app_name="foo")
+        d = WriteAccessAllowed(web_app_name="foo")
+        e = WriteAccessAllowed(web_app_name="bar")
+
+        assert a == b
+        assert hash(a) == hash(b)
+
+        assert a != c
+        assert hash(a) != hash(c)
+
+        assert c == d
+        assert hash(c) == hash(d)
+
+        assert c != e
+        assert hash(c) != hash(e)
